@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_cleaner.pl,v 1.4 2004/09/22 08:11:49 yeupou Exp $
+# $Id: sv_cleaner.pl,v 1.5 2004/11/22 08:25:47 yeupou Exp $
 #
 #  Copyright 2003 (c) Mathieu Roy <yeupou@gnu.org> 
 #
@@ -122,6 +122,48 @@ my $result = DeleteGroups("status='I' AND register_time < $date");
 print LOG strftime "[$script] %c ---- deleted $result inactive groups\n", localtime if $result > 0;
 
 
+#######################################################################
+##
+## Remove deleted projects, no matter their registration time
+##
+#######################################################################
+ 
+my $result = DeleteGroups("status='D'");
+
+print LOG strftime "[$script] %c ---- deleted $result deleted groups\n", localtime if $result > 0;
+
+
+
+#######################################################################
+##
+## Remove too old form_id, forms created more than two days ago an still
+## not submitted
+##
+#######################################################################
+ 
+my ($year, $month, $day) = split(",", `date -d "1 days ago" +%Y,%m,%d`);
+my $date = timelocal("0","0","0",$day,($month-1),($year-1900));
+
+my $result = DeleteDB("form", "timestamp < $date");
+
+print LOG strftime "[$script] %c ---- deleted $result outdated form ids\n", localtime if $result > 0;
+
+
+#######################################################################
+##
+## Remove too old sessions, session older than one year
+##
+#######################################################################
+ 
+my ($year, $month, $day) = split(",", `date -d "1 year ago" +%Y,%m,%d`);
+my $date = timelocal("0","0","0",$day,($month-1),($year-1900));
+
+my $result = DeleteDB("session", "time < $date");
+
+print LOG strftime "[$script] %c ---- deleted $result sessions older than one year\n", localtime if $result > 0;
+
+
+
 #######################################################################
 ##
 ## Project in holding status for too long should be pending
