@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_users.pl,v 1.37 2004/09/22 08:11:50 yeupou Exp $
+# $Id: sv_users.pl,v 1.44 2004/10/19 12:30:00 yeupou Exp $
 #
 #  Copyright 2001      (c) Loic Dachary <loic--at--gnu.org> (sv_cvs.pl)
 #            2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
@@ -65,12 +65,15 @@ my $userdel = "userdel";
 my $userx_prefix;
 
 my $min_uid = "5000";
-my $nobody_uid = 
+my $nobody_uid = "65534";
 
+# deprecated, replaced by webgroup
 my $one_group = 0;
+my $webgroup = 0;
 
-my $svusersgroup = "svusers"; # this could be configurable, however it
-                              # does not seems very important right now.
+my $svusers = "svusers"; # this could be configurable, however it
+                         # does not seems very important right now.
+my $svusers_gid = getgrnam($svusers);
 
 my $subversions = AreWeOnSubversions();
 
@@ -83,6 +86,7 @@ eval {
 			 "useradd=s" => \$useradd,
 			 "usermod=s" => \$usermod,
 			 "userdel=s" => \$userdel,
+			 "webgroup" => \$webgroup,
 			 "one-group" => \$one_group);
 };
 
@@ -93,7 +97,7 @@ Usage: $0 [project] [OPTIONS]
 Update the system to reflect the database, about users.
 Normally, sv_groups should run just before.
 
-Note that users are associated with the group svusers.
+Note that users are associated with the group $svusers.
 
   -h, --help                   Show this help and exit
   -d, --debug                  Do nothing, print everything
@@ -106,6 +110,10 @@ Note that users are associated with the group svusers.
       --usermod=[usermod]      Specify usermod binary
       --userdel=[userdel]      Specify userdel binary
 
+      --webgroup               For each projects, add users in two group,
+                               including one with the prefix web.
+                               (this was the default behavior in =< 1.0.4)
+
 Savane version: $version
 EOF
 exit(1);
@@ -209,7 +217,7 @@ foreach my $line (GetDB("user_group,groups,user",
 
     unless ($group eq 'www' && $subversions) {
 	push(@groups, $group);
-	push(@groups, "web".$group) unless $one_group;
+	push(@groups, "web".$group) if $webgroup;
     } else {
 	# www is a special group normally used to give
 	# a user write access on the whole CVSROOT of 
@@ -248,28 +256,39 @@ print LOG strftime "[$script] %c - database infos grabbed\n", localtime;
 #######################################################################
 
 # /etc/passwd (/etc/shadow...):
-#    Create an hash that contains users infos from these files,
+#    - Create an hash that contains users infos from these files,
 #    as lists for each user.
 #    ( @{$etc_password{$user}} )
-#    Find what is the maximum id number known.
-#    Additionally, create a list of users. 
+#    - Find what is the maximum id number known.
+#    - Additionally, create a list of users. 
+#    - To be ignored list groups that were not created by sv_users, since they
+#    do not belongs to svusers group: their account will remain untouched
 my %etc_password;
 my @etc_users;
+my %etc_password_tobeignored;
 my $etc_password_maxid = -1;
-while (my @entry = getpwent()) {
-    push(@etc_users, $entry[0]);
- 
-    # Ignore special users like webcvs, anoncvs and nobody
-    # The first ones are supposed to be under 5000 (min uid). The latest
-    # will require special attention later, to avoid uid conflicts, being
-    # usually equal to 65534. To avoid troubles, we save its value.
+while (my @entry = getpwent()) { 
+    # Save the uid of nobody, if found
     if ($entry[0] eq 'nobody') { $nobody_uid = $entry[2]; }
+
+    # Ignore any user not belonging to svusers: we wont mess with accounts not
+    # created by the backend itself. We also add them in an hash, to make
+    # sure no action we be taken related to these accounts
+    if ($entry[3] ne $svusers_gid) {
+	print "DBG etc: user $entry[0] will be ignored, belongs to group $entry[3]\n" if $debug;
+	$etc_password_tobeignored{$entry[0]} = 1;
+	next;
+    }
+
+    # Ignore special users like webcvs, anoncvs and nobody
+    # The first ones are supposed to be under 5000 (min uid).
     next if($entry[0] eq 'anoncvs' || $entry[0] eq 'webcvs' || $entry[0] eq 'nobody');
     
+    push(@etc_users, $entry[0]);
     $etc_password_maxid = $entry[2] > $etc_password_maxid ? $entry[2] : $etc_password_maxid;
     
     $etc_password{$entry[0]} = [ @entry ];
-    print "DBG etc: user $entry[0]\t\t maxid $etc_password_maxid\n" if $debug;
+    print "DBG etc: user $entry[0]\t\t maxid $etc_password_maxid \t group $entry[3]\n" if $debug;
 }
 $etc_password_maxid++;
 # If we did not reached the minimal uid, set it as maxid
@@ -328,6 +347,7 @@ foreach my $user (@etc_users) {
 
 foreach my $user (@db_users) {
     next if $user eq "None";
+    next if $user eq $etc_password_tobeignored{$user};
     unless ($seen_in_etc{$user}) {
 	push(@only_in_db, $user);
 	print "DBG compare: $user is seen only in database\n" if $debug;
@@ -348,7 +368,9 @@ foreach my $user (@well_known) {
     # longer member of any project: we just list
     # Second test: looks for the marked as D users
     if (!exists($db_user_group{$user}) || $db_user{$user}->[5] eq 'D') {
-	push(@to_be_removed, $user);
+	# Last test: check if we are not dealing with an account ignored
+	# (it should not be necessary at this point but it does not cost much)
+	push(@to_be_removed, $user) unless $etc_password_tobeignored{$user};
     }
 }
 
@@ -362,6 +384,7 @@ print LOG strftime "[$script] %c - comparison done\n", localtime;
 
 # Add users only in database, missing on the system
 foreach my $user (@only_in_db){
+    next if $etc_password_tobeignored{$user};
 
     # We only create an account for project's members
     if (exists($db_user_group{$user})) {
@@ -375,29 +398,37 @@ foreach my $user (@only_in_db){
 
 	print "DBG create: $user belongs to $groups\n" if $debug;
 	unless ($debug) {
-
+		
 	    # Make a backup if a home user already exists
-	    `rm -fr $home.old` if -e "$home.old";
-	    `mv $home $home.old` if -d "$home";
-	        
+	    system("/bin/rm", "-fr", "$home.old") if -e "$home.old";
+	    system("/bin/mv", $home, "$home.old") if -d "$home";
+	    
 	    # Build the home dir
-	    `mkdir -p $home`; 
+	    system("/bin/mkdir", "-p", $home); 
 	    mkdir("$home/.ssh"); 
 	    mkdir("$home/.gnupg"); 
-	    `touch $home/.savannah $home/.ssh/authorized_keys`;
-
+	    system("/usr/bin/touch", "$home/.savane", "$home/.ssh/authorized_keys");
+	    
 	    # Create a proper account
 	    # (this should be done after the building of the home dir,
 	    # because some versions of useradd tries foolishly to create
 	    # the user home, and fail due to missing directories in the path)
-	    `$useradd -p '*' -u $etc_password_maxid -d $home -c \"$realname\" -s $sys_shell -g svusers -G $groups $user`;
+	    system($useradd, 
+		   "-p", "*",
+		   "-u", $etc_password_maxid,
+		   "-d", $home,
+		   "-c", $realname,
+		   "-s", $sys_shell,
+		   "-g", $svusers,
+		   "-G", $groups,
+		   $user);
 	    
 	    # Add SSH public key
 	    if ($authorized_keys ne "NULL") {
 		$ssh_keys_count = UserAddSSHKey($user, $authorized_keys);
 	    }
-
-
+	    
+	    
 	    # Add GPG key
 	    if ($gpg_keys ne "NULL") {
 		# For gpg, I have to think about. Would we accept only gpg
@@ -405,17 +436,14 @@ foreach my $user (@only_in_db){
 		$gpg_keys_count = UserAddGPGKey($user, $gpg_keys);
 	    }
 	    
-
+	    
 	    # Fix modes and ownership
-	    `chmod 2755 $home`;
-	    `chmod 755 $home/.ssh  $home/.gnupg`;
-	    `chmod 600 $home/.ssh/authorized_keys`;
-	    `chown -R $user.svusers $home`;
-	    # The following was done in sv_cvs
-	    # `chown -R $user.anoncvs $home/.ssh $home/.savannah`;
+	    system("/bin/chmod", "2755", $home);
+	    system("/bin/chmod", "755", "$home/.ssh", "$home/.gnupg");
+	    system("/bin/chmod", "600", "$home/.ssh/authorized_keys");
+	    system("/bin/chown", "-R", "$user.$svusers", $home);
 	    
 	}
-	
 	# Increment the uid for the next user, avoid the special value 
 	# attributed to nobody.
 	$etc_password_maxid++;	
@@ -432,6 +460,7 @@ print LOG strftime "[$script] %c - account creation done\n", localtime;
 # Remove users marked as D in the database.
 # This is the safest way to remove users quitting savannah.
 foreach my $user (@to_be_removed) {
+    next if $etc_password_tobeignored{$user};
 
     print LOG strftime "[$script] %c ---- delete $user account\n", localtime;
     print "DBG delete: $user is marked as D or no longer member of any project\n" if $debug;
@@ -444,6 +473,7 @@ print LOG strftime "[$script] %c - account deletion done\n", localtime;
 # Update existing users.
 # These users are in the database and on the system.
 foreach my $user (@well_known) {
+    next if $etc_password_tobeignored{$user};
 
     # Get usual infos
     my ($user_name,
@@ -473,22 +503,27 @@ foreach my $user (@well_known) {
 
     if (@groups_list ne @groups_list_etc) {
 	my $groups = join(",", @groups_list);
-	`$usermod -G $groups $user` unless $debug;
+	
+	system($usermod,
+	       "-G", $groups,
+	       $user) unless $debug;
+
 	print LOG strftime "[$script] %c ---- update $user groups\n", localtime;
 	print "DBG update: $user belongs to \t[db+sys]\t".join(", ", @groups_list)."\t[sys]\t".join(", ", @groups_list_etc)."\n" if $debug;
+	
     } else {
 	print "DBG update: NO UPDATE for user $user that belongs to \t[db+sys]\t".join(", ", @groups_list)."\t[sys]\t".join(", ", @groups_list_etc)."\n" if $debug;
     }
-
+    
     # Update groups: check if the user is removed from a group in the
     # database.
 
 
     # Update name (name, email) if not accurate.
     my $password_realname = $etc_password{$user}->[6];
-    my $expected_realname = "$realname";
+    my $expected_realname = $realname;
     if ($password_realname ne $expected_realname) {
-	`$usermod -c \"$expected_realname\" $user` unless $debug;
+	system($usermod, "-c", $expected_realname, $user) unless $debug;
 	print LOG strftime "[$script] %c ---- update $user /etc/passwd realname\n", localtime;
     }
 
@@ -498,13 +533,13 @@ foreach my $user (@well_known) {
     my $password_home = $etc_password{$user}->[7];
     my $expected_home = GetUserHome($user);
     if ($password_home ne $expected_home) {
-	`$usermod -d \"$expected_home\" $user` unless $debug;
-	`mkdir -p $expected_home && rm -rf $expected_home` unless $debug;
-	`mv -f $password_home $expected_home` unless $debug;
+	system($usermod, "-d", $expected_home, $user) unless $debug;
+	system("/bin/mkdir", "-p", $expected_home) unless $debug;
+	system("/bin/rm", "-rf", $expected_home) unless $debug;
+	system("/bin/mv", "-f", $password_home, $expected_home) unless $debug;
 	print LOG strftime "[$script] %c ---- update $user /etc/passwd homedir\n", localtime;
     }
-
-
+    
     # Update SSH public keys if not accurate and only if the user
     # got the default shell.
     # In other cases, we do not mess with the way login rights are 
