@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: change.php,v 1.9 2004/09/29 12:54:38 yeupou Exp $
+# $Id: change.php,v 1.10 2004/11/22 08:25:48 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
@@ -45,7 +45,7 @@ if ($update)
 	{ fb(_("You must supply a new real name."), 1); }
       else
 	{
-	  $newvalue = strtr($newvalue, "\'\"", "   ");
+	  $newvalue = strtr($newvalue, "\'\"\,", "     ");
 	  $success = db_query("UPDATE user SET realname='".addslashes($newvalue)."' WHERE user_id=".user_getid());
 	  if ($success)
 	    { fb(_("Real Name updated.")); }
