@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: lostlogin.php,v 1.14 2004/09/29 12:54:38 yeupou Exp $
+// $Id: lostlogin.php,v 1.15 2004/11/22 08:25:48 yeupou Exp $
 //
 //
 // Copyright 1999-2000 (c) The SourceForge Crew
@@ -43,14 +43,14 @@ if (db_numrows($res_lostuser) < 1) {
 }
 $row_lostuser = db_fetch_array($res_lostuser);
 
-if ($Update && $form_pw && !strcmp($form_pw,$form_pw2)) {
-	db_query("UPDATE user SET "
-		. "user_pw='" . md5($form_pw) . "',"
-		. "confirm_hash='' WHERE "
-		. "confirm_hash='$confirm_hash'");
-
-
-	session_redirect($GLOBALS['sys_home']);
+if ($update && form_check($form_id) && $form_pw && !strcmp($form_pw,$form_pw2)) {
+  db_query("UPDATE user SET "
+	   . "user_pw='" . md5($form_pw) . "',"
+	   . "confirm_hash='' WHERE "
+	   . "confirm_hash='$confirm_hash'");
+  
+  form_clean($form_id);
+  session_redirect($GLOBALS['sys_home']);
 }
 
 $HTML->header(array('title'=>_("Lost Password Login")));
@@ -59,16 +59,17 @@ print '<h3>'._("Lost Password Login").'</h3>';
 print '<p>'._("Welcome").', '.$row_lostuser['user_name'].'.';
 print ' '._("You may now change your password").'.</p>';
 
+print form_header($PHP_SELF);
+
 print '<form action="lostlogin.php">';
 print '<div class="inputfield"><h5>'._("New Password:").'</h5>';
-print '<input type="password" name="form_pw"></div>';
+print form_input("password", "form_pw").'</div>';
 
 print '<div class="inputfield"><h5>'._("New Password (repeat):").'</h5>';
-print '<input type="password" name="form_pw2"></div>';
+print form_input("password", "form_pw2").'</div>';
 
-print '<input type="hidden" name="confirm_hash" value="'.$confirm_hash.'">';
-print '<p><input type="submit" name="Update" value="'._("Update").'"></p>';
-print '</form>';
+print form_input("hidden", "confirm_hash", $confirm_hash);
+print form_footer();
 
 $HTML->footer(array());
 
