@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: group_type.php,v 1.26 2004/09/22 08:11:50 yeupou Exp $
+# $Id: group_type.php,v 1.27 2004/11/22 08:25:48 yeupou Exp $
 #
 #  Copyright (C) 2002-2004 Mathieu Roy <yeupou--at--gnu.org>
 #
@@ -204,7 +204,7 @@ else
   # ########### Help
 
   print '
-<p>Basic Help: host means hostname (as savannah.gnu.org), dir means directory (as /usr/local/savannah), url means -well- url (as http:#savannah.gnu.org/blah ).
+<p>Basic Help: host means hostname (as savannah.gnu.org), dir means directory (as /var/www/savannah), url means -well- url (as http://savannah.gnu.org/blah ).
 
 <p class="warn">Everytime a project\'s unix_group_name should appear, use the special string %PROJECT.
 
@@ -319,12 +319,12 @@ can use download area.
 
 <h3>Mailing list:</h3>
 
-<font class="warn">Help: Everytime a mailing-list name should appear, use the special string %LIST. Note that if you do not want the Savannah software to interact with your mail host (for instance to truly create mailing list), do not fill the mail host information.</font>
+<font class="warn">Help: Everytime a mailing-list name should appear, use the special string %LIST.<br />Note that if you do not want the Savane Frontend to interact with your mail host (for instance to truly create mailing list), do not fill the mail host information, the backend does not need that field to be set!</font>
 
 <br />
 <br /><INPUT TYPE="CHECKBOX" NAME="form_can_use_mailing_list" VALUE="1"'.( ($row_grp['can_use_mailing_list']==1) ? ' checked="checked"' : '' ).'>
 Can use mailing-list.<br />
-<br />Mailing List Host:<br />
+<br />Mailing List Host (DEPRECATED):<br />
 <input type="text" name="form_mailing_list_host" value="'.$row_grp['mailing_list_host'].'" size="'.$textfield_size.'">
 
 <br /><br />Mailing list address (would be %LIST@gnu.org for GNU projects at sv.gnu.org):<br />
