@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: html.php,v 1.52 2004/09/22 08:11:51 yeupou Exp $
+# $Id: html.php,v 1.53 2004/11/22 08:25:48 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -166,7 +166,7 @@ function html_image ($src,$args,$display=1)
     }
 }
 
-function html_build_list_table_top ($title_arr,$links_arr=false)
+function html_build_list_table_top ($title_arr,$links_arr=false,$table=true)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_list_table_top ';
   /*
@@ -177,8 +177,13 @@ function html_build_list_table_top ($title_arr,$links_arr=false)
   */
   GLOBAL $HTML;
 
-  $return = '
-	<table class="box">
+  if ($table)
+    {
+     $return = '
+  <table class="box">';
+    }
+
+     $return .= '
 		<tr>';
 
   $count=count($title_arr);
@@ -266,7 +271,15 @@ function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz
   return $return;
 }
 
-function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_val='xzxz',$show_100=true,$text_100='None', $show_any=false,$text_any='Any')
+function html_build_select_box_from_arrays ($vals,
+					    $texts,
+					    $select_name,
+					    $checked_val='xzxz', #4
+					    $show_100=true,
+					    $text_100='None', #6
+					    $show_any=false,
+					    $text_any='Any', #8
+					    $show_unknown=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box_from_arrays ';
   /*
@@ -305,6 +318,12 @@ function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_v
 		<select name="'.$select_name.'">';
 
 
+  # We want the "Default" on item initial post, only at this momement
+  if ($show_unknown)
+    {
+      $return .= "\n<option value=\"!unknown!\">"._("Unknown")."</option>";
+    }
+
   #we don't always want the default any  row shown
   if ($show_any)
     {
@@ -352,7 +371,7 @@ function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_v
   return $return;
 }
 
-function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=true,$text_100='None',$show_any=false,$text_any='Any')
+function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=true,$text_100='None',$show_any=false,$text_any='Any',$show_unknown=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box  ';
   /*
@@ -368,7 +387,7 @@ function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=tr
 		The fifth parameter is optional - what to call the '100 row' defaults to none
   */
 
-  return html_build_select_box_from_arrays (utils_result_column_to_array($result,0),utils_result_column_to_array($result,1),$name,$checked_val,$show_100,$text_100,$show_any,$text_any);
+  return html_build_select_box_from_arrays (utils_result_column_to_array($result,0),utils_result_column_to_array($result,1),$name,$checked_val,$show_100,$text_100,$show_any,$text_any,$show_unknown);
 }
 
 function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',$show_100=true,$text_100='None', $show_any=false,$text_any='Any',$show_value=true)
@@ -479,7 +498,7 @@ function html_select_permission_box ($artifact, $row, $level="member")
     }
   
   print '
-    <td>
+    <td align="center">
       <select name="'.$artifact.'_user_'.$num.'">';
   if ($default)
     {
@@ -542,7 +561,7 @@ function html_select_restriction_box ($artifact, $row, $level="group", $notd=0)
   if (!$notd) 
     {
       print '
-    <td>';
+    <td align="center">';
     }
 
   print '
@@ -599,7 +618,7 @@ function html_select_typedir_box ($input_name, $current_value)
 
   # put some information
   print '<br /><font class="italic">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br /> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br />
-(If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savannah-dev@gnu.org to get information about that)</font><br />';
+(If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savane-dev@gna.org to get information about that)</font><br />';
 
 }
 
@@ -613,7 +632,7 @@ function html_select_typedir_box ($input_name, $current_value)
 function html_select_theme_box ($input_name="user_theme", $current=0)
 {
 
-  print  '
+  print '
 		<select name="'.$input_name.'">';
 
   # usual themes
@@ -892,7 +911,7 @@ function html_member_explain_roles ()
   print '<p>';
   print _("Trackers Managers can fully manage the trackers items, including assigning items to technicians, reassign items over trackers and projects, changing priority and status of items - but they cannot configure the trackers.");
   print '<p>';
-  print _("Project Admins can manage members, configure the trackers, post jobs, and add mailing-list. They actually also have both technician and manager rights on every tracker.");
+  print _("Project Admins can manage members, configure the trackers, post jobs, and add mailing-list. They actually also have manager rights on every tracker and are allowed to read private items.");
   print '<p>';
 }
 
