@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: i18n.php,v 1.11 2004/07/29 19:42:10 tchernobog Exp $
+# $Id: i18n.php,v 1.12 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Stphane Urbanovski <s.urbanovski@ac-nancy-metz.fr>
 #                          Mathieu Roy <yeupou--at--gnu.org>              
@@ -25,12 +25,16 @@
 # the user's navigator preferences. The locale is used by gettext and strftime
 # functions.
 
+# Should we use _ENV["LANG"] also?
+
+
 # Get the user's prefered language from the navigator sended headers :
 $navigatorLanguages = explode(",",getenv("HTTP_ACCEPT_LANGUAGE"));
 
 # Set the default language :
 $locale = $GLOBALS['sys_default_locale'];
 
+
 # Table of supported languages :
 # "lang" => "associated prefered sublanguage"
 $supportedLanguages = array(
@@ -58,11 +62,13 @@ while (list(, $lng) = each ($navigatorLanguages)) {
     $sublocale = $curlocale."_".strtoupper(substr($lng,3,2));
     if ( isset($supportedLanguages[$sublocale] )) {
       $locale = $curlocale."_".$supportedLanguages[$sublocale];
+      define(SV_LANG, $curlocale."-".$supportedLanguages[$sublocale]);
       break; 
     }
   } 
   if ( isset($supportedLanguages[$curlocale] )) { 
     $locale = $curlocale."_".$supportedLanguages[$curlocale];
+    define(SV_LANG, $curlocale."-".$supportedLanguages[$curlocale]);
     break; 
   }
   
@@ -72,7 +78,7 @@ while (list(, $lng) = each ($navigatorLanguages)) {
 setlocale(LC_ALL, $locale);
 
 # Gettext (i18n) configs :
-textdomain('savannah');
+textdomain('savane');
 
 
 #print "[".$locale.",".setlocale(LC_ALL,0)."]"; //debug
