@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: member.php,v 1.4 2004/03/13 18:22:06 yeupou Exp $
+# $Id: member.php,v 1.5 2004/11/22 08:25:48 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -30,7 +30,6 @@ function member_add ($user_id, $group_id, $status='')
   
   if(!member_check($user_id,$group_id) || user_is_super_user())
     {
-      # member check will always return true if with member_check
       $sql = "INSERT INTO user_group (user_id, group_id, admin_flags) VALUES ($user_id, $group_id, '$status')";
 
       $result = db_query($sql);
@@ -180,7 +179,7 @@ function member_check ($user_id=0, $group_id, $flag=0, $strict=0)
 	{ $value = group_gettypepermissions($group_id, $flag_tracker); }
       if (!$value)
 	{ $value = "ERROR"; }
-        
+  
       # compare the value and what is asked
       if ($value == $flag_level)
 	{
@@ -211,6 +210,67 @@ function member_check ($user_id=0, $group_id, $flag=0, $strict=0)
 	}
     }
 }
+# Additional function to check whether a member is pending for a group
+# (partly member, so)
+function member_check_pending ($user_id=0, $group_id)
+{
+  $result = db_query("SELECT user_id FROM user_group WHERE user_id='$user_id' AND group_id='$group_id' AND admin_flags='P'");
+  if (db_numrows($result)) 
+    {
+      return true;
+    }
+  else 
+    {
+      return false;
+    }
+}
+
+# Function like member_check() only checking if one specific user is allowed
+# to read private content.
+# This stuff was not included in member_check() to ease development, nothing
+# else.
+function member_check_private ($user_id=0, $group_id)
+{
+   # get the current user_id if missing
+  if (!$user_id)
+    {
+      if (!user_isloggedin()) 
+	{
+	  # not able to get a valid user id
+	  return false;	
+	}
+      else
+	{ 
+	  if (user_is_super_user())
+	    {
+	      # site admins always return true
+	      return true;
+	    }
+	  else 
+	    {
+	      # any other case, define the user_id needed later.
+	      $user_id = user_getid(); 
+	    }
+	}
+    }
+  
+  # check if its a project admin. If so, give access
+  if (member_check($user_id, $group_id, 'A')) 
+    { 
+      return true;
+    }
+
+  # determine whether someone is member allowed to read private date
+  # of a project or not
+  if (db_numrows(db_query("SELECT user_id FROM user_group WHERE user_id='$user_id' AND group_id='$group_id' AND admin_flags<>'P' AND privacy_flags='1'")))
+    {
+      return true;
+    }
+
+  # if we end up here, it must be false
+  return false;
+}
+
 
 # permit to keep the "simple" syntax of member_check but also
 # to be able to generate this simple syntax on-fly depending on 
