@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: menu.php,v 1.111 2004/09/22 08:11:51 yeupou Exp $
+# $Id: menu.php,v 1.116 2004/11/26 15:50:33 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -37,11 +37,11 @@ function menu_print_sidebar($params)
 
   if ($GLOBALS['sys_logo_name']) 
     {
-      print '          '.utils_link($GLOBALS['sys_home'], html_image($GLOBALS['sys_logo_name'],array('alt'=>sprintf(_("%s Homepage"), $GLOBALS['sys_name'])), 0));
+      print '          '.utils_link($GLOBALS['sys_home'], html_image($GLOBALS['sys_logo_name'],array('alt'=>sprintf(_("Back to %s Homepage"), $GLOBALS['sys_name'])), 0));
     }
   else
     {
-      print '          <br />'.utils_link($GLOBALS['sys_home'],sprintf(_("%s Homepage"), $GLOBALS['sys_name']));
+      print '          <br />'.utils_link($GLOBALS['sys_home'], $GLOBALS['sys_name'], 0, 1, sprintf(_("Back to %s Homepage"), $GLOBALS['sys_name']));
     }
 
   print '
@@ -54,6 +54,7 @@ function menu_print_sidebar($params)
     {
       print menu_loggedin($params['title'], $params['toptab'], $params['group']);
     }
+  print menu_thispage();
   print menu_search();
   # Site Admin menu added here
   if (user_is_super_user()) 
@@ -81,8 +82,9 @@ function menu_site_admin()
   global $HTML;
   $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Administration")); 
   $HTML->menu_entry($GLOBALS['sys_home'].'admin/',_("Main page"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'admin/approve-pending.php',_("Pending projects"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'task/?group='.$GLOBALS['sys_unix_group_name'].'&amp;category_id=1&amp;status_id=1&amp;go_report=Apply',_("Pending projects"));
   $HTML->menu_entry($GLOBALS['sys_home'].'news/approve.php?group='.$GLOBALS['sys_unix_group_name'],_("Site news approval"));
+
   $HTML->menuhtml_bottom();
 
 }
@@ -90,7 +92,7 @@ function menu_site_admin()
 function menu_search() 
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_search() ';
-  global $HTML;
+  global $HTML,$group_id;
   $HTML->menuhtml_top(_("Search"));
   print '       <li class="menusearch">';
   search_box();  
@@ -115,8 +117,48 @@ function menu_projects()
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_projects() ';
   global $HTML;
   $HTML->menuhtml_top(_("Hosted Projects"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'register/',_("Register New Project"), user_isloggedin());
- $HTML->menu_entry($GLOBALS['sys_home'].'search/index.php?type_of_search=soft&amp;words=%%%',_("Full List"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'register/',
+		    _("Register New Project"), 
+		    user_isloggedin(),
+		    sprintf(_("Register your project at %s"),$GLOBALS['sys_name']));
+ $HTML->menu_entry($GLOBALS['sys_home'].'search/index.php?type_of_search=soft&amp;words=%%%',
+		   _("Full List"),
+		   1,
+		   _("Browse the full list of hosted projects"));
+ $HTML->menu_entry($GLOBALS['sys_home'].'stats/',
+		   _("Statistics"),
+		   1,
+		   sprintf(_("Browse statistics about %s"),$GLOBALS['sys_name']));
+  $HTML->menuhtml_bottom();
+}
+
+# Toolbox: not very happy with the name "This Page"... please propose
+# something better
+function  menu_thispage()
+{
+  global $HTML;
+  # FIXME: does not handle the /users and /projects cases
+  $HTML->menuhtml_top(_("This Page"));
+  if ($_SERVER["REQUEST_METHOD"] == "POST") 
+    {
+      if ($GLOBALS['group_name'])
+	{ $extraurl .= "group=".$GLOBALS['group_name']."&amp;"; }
+      if ($GLOBALS['item_id'])
+	{ $extraurl .= "func=detailitem&amp;item_id=".$GLOBALS['item_id']."&amp;"; }
+    }
+  else
+    {
+      $extraurl = $_SERVER["QUERY_STRING"];
+    }
+
+  $HTML->menu_entry($_ENV["SCRIPT_NAME"]."?reload=1&amp;".$extraurl,
+		    _("Clean Reload"),
+		    1,
+		    _("Reload the page without risk of reposting data"));
+  $HTML->menu_entry($_ENV["SCRIPT_NAME"]."?printer=1&amp;".$extraurl,
+		    _("Printer Version"), 
+		    1,
+		    _("Show this page with a style adapted to printers"));
   $HTML->menuhtml_bottom();
 }
 
@@ -126,8 +168,14 @@ function menu_help()
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_help() ';
   global $HTML;
   $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Help"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'support/?group='.$GLOBALS['sys_unix_group_name'],_("Get Support"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'people/',_("Contributor Wanted"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'support/?group='.$GLOBALS['sys_unix_group_name'],
+		    _("Get Support"),
+		    1,
+		    sprintf(_("Get help from the Admins of %s"), $GLOBALS['sys_name']));
+  $HTML->menu_entry($GLOBALS['sys_home'].'people/',
+		    _("Contributor Wanted"),
+		    1,
+		    _("Browse the list of request for contributions"));
   $HTML->menuhtml_bottom();
 }
 
@@ -137,7 +185,10 @@ function menu_documentation()
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_documentation() ';
   GLOBAL $HTML;
   $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Documentation"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'faq/?group='.$GLOBALS['sys_unix_group_name'],_("User Docs (FAQ)"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'faq/?group='.$GLOBALS['sys_unix_group_name'],
+		    _("User Docs (FAQ)"),
+		    1,
+		    _("Documentation dedicated to any users, including Project Admins"));
   if (user_can_be_super_user()) 
     {
       $HTML->menu_entry($GLOBALS['sys_home'].'docs/admin.php',_("Server Admin Docs"));
@@ -151,7 +202,10 @@ function menu_documentation()
     {
       $HTML->menu_entry($GLOBALS['sys_home'].'docs/webalizer.php',_("Statistics"));
     }
-  $HTML->menu_entry($GLOBALS['sys_home'].'contact.php',_("Contact Us"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'contact.php',
+		    _("Contact Us"),
+		    1,
+		    sprintf(_("Contact address of %s Admins"),$GLOBALS['sys_name']));
   $HTML->menuhtml_bottom();
 }
 
@@ -172,11 +226,23 @@ function menu_loggedin($page_title, $page_toptab=0, $page_group=0)
     }
   if (user_can_be_super_user() && !user_is_super_user()) 
     {
-      $HTML->menu_entry($GLOBALS['sys_home'].'account/su.php?action=login&amp;uri='.urlencode($GLOBALS['REQUEST_URI']), _("Become Superuser"));      
+      $HTML->menu_entry($GLOBALS['sys_home'].'account/su.php?action=login&amp;uri='.urlencode($GLOBALS['REQUEST_URI']), 
+			_("Become Superuser"),
+			1,
+			_("Superuser rights are required to perform site admin tasks"));      
     }
-  $HTML->menu_entry($GLOBALS['sys_home'].'my/',_("My Items"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'my/groups.php',_("My Groups"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'account/',_("My Account Conf"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'my/',
+		    _("My Items"),
+		    1,
+		    _("Browse my items (bugs, tasks, bookmarks...)"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'my/groups.php',
+		    _("My Groups"),
+		    1,
+		    _("List the groups I belong to"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'account/',
+		    _("My Account Conf"),
+		    1,
+		    _("Account configuration: authentication, cosmetics preferences..."));
   if (!$GLOBALS['HTTP_POST_VARS']) 
     {
       $bookmark_title = "";
@@ -191,9 +257,15 @@ function menu_loggedin($page_title, $page_toptab=0, $page_group=0)
 
  if (user_is_super_user()) 
     {
-      $HTML->menu_entry($GLOBALS['sys_home'].'account/su.php?action=logout&amp;uri='.urlencode($GLOBALS['REQUEST_URI']), _("Logout Superuser"));      
+      $HTML->menu_entry($GLOBALS['sys_home'].'account/su.php?action=logout&amp;uri='.urlencode($GLOBALS['REQUEST_URI']), 
+			_("Logout Superuser"),
+			1,
+			_("End the Superuser session, go back to normal user session"));      
     }
-  $HTML->menu_entry($GLOBALS['sys_home'].'account/logout.php',_("Logout"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'account/logout.php',
+		    _("Logout"),
+		    1,
+		    _("End the session, remove the session cookie"));
   $HTML->menuhtml_bottom();
 }
 
@@ -203,10 +275,16 @@ function menu_notloggedin()
   global $HTML;
   $HTML->menuhtml_top(_("Login Status:"));
   print '
-        <li class="menuitem"><font class="error">'._("Not Logged In").'</font></li>';
+        <li class="menuitem"> <font class="error">'._("Not Logged In").'</font></li>';
   $HTML->menu_entry($GLOBALS['sys_home'].'faq/?question='.urlencode("1._Why_log_in.txt"),_("Why Log In?"));
-  $HTML->menu_entry($GLOBALS['sys_https_url'].$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($GLOBALS['REQUEST_URI']),_("Login via SSL"));
-  $HTML->menu_entry($GLOBALS['sys_https_url'].$GLOBALS['sys_home'].'account/register.php',_("New User via SSL"));
+  $HTML->menu_entry($GLOBALS['sys_https_url'].$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($GLOBALS['REQUEST_URI']),
+		    _("Login via SSL"),
+		    1,
+		    _("Login page - you must have registered an account first"));
+  $HTML->menu_entry($GLOBALS['sys_https_url'].$GLOBALS['sys_home'].'account/register.php',
+		    _("New User via SSL"),
+		    1,
+		    _("Account registration form"));
   $HTML->menuhtml_bottom();
 }
 
