@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: project_home.php,v 1.109 2004/09/22 08:11:51 yeupou Exp $
+# $Id: project_home.php,v 1.110 2004/11/22 08:25:48 yeupou Exp $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
 # Copyright 2000-2003 (c) Free Software Foundation
@@ -54,33 +54,46 @@ print '
 ';
 
 print $HTML->box_top(_("Membership Info"));
+print '<font class="smaller">';
 $adminsnum = db_numrows($res_admin);
+$j = 0;
 if ($adminsnum > 0)
 {
 
-  print _("Project Admins").':';
+  print _("Project Admins:");
   while ($row_admin = db_fetch_array($res_admin))
 {
-    print "<br />&nbsp; - ".utils_link($GLOBALS['sys_home']."users/".$row_admin[user_name], $row_admin[realname]);
+  print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
+    print "&nbsp; - ".utils_link($GLOBALS['sys_home']."users/".$row_admin[user_name], $row_admin[realname]);
   }
 }
 
 #count of developers on this project
 $membersnum = db_fetch_array(db_query("SELECT COUNT(*) AS count FROM user_group WHERE group_id=$group_id AND admin_flags<>'P'"));
-print '<br /><br />'._("Members").': <font class="bold">'.$membersnum[count].'</font>';
+print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
+print _("Members").': <font class="bold">'.$membersnum[count].'</font>';
 
 # if member = 1, it's obviously (or it should be) the project admin
 # if there's no admin, we need to get access to the list
 # But we show it anyway: this page can be used for request for membership,
 # provide more info that the little infobox.
-print '<br />&nbsp; '.utils_link($GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name, "[View&nbsp;&nbsp;Members]");
-
+print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
+print utils_link($GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name, _("[View Members]")).'</font>';
 
 print $HTML->box_bottom();
-print '<br />';
+print '<br />
+';
 print $HTML->box_top(_("Group identification"));
-print '&nbsp; - #'.$group_id;
-print '<br />&nbsp; - '.$group_name;
+print '<font class="smaller">';
+print _("Id:").' <b>#'.$group_id.'</b>';
+$j = 0;
+print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
+print _("System Name:").' <b>'.$group_name.'</b>';
+print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
+print _("Name:").' <b>'.$project->GetName().'</b>';
+print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
+print _("Group Type:").' <b>'.$project->getTypeName().'</b>';
+print '</font>';
 print $HTML->box_bottom();
 
 
@@ -175,7 +188,11 @@ if ($GLOBALS[sys_group_id] == $group_id)
 
       print utils_link($GLOBALS['sys_home'].'admin/approve-pending.php',
 		       html_image("admin.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Server Admin"))).'&nbsp;'._("Pending Projects List"));
-      print ' (<b>'.number_format(stats_getprojects_pending()).'</b> '._("registrations pending").')';
+      $registration_count = number_format(stats_getprojects_pending());
+      if ($registration_count > 1) 
+	{ print " (".sprintf(_("%s registrations pending"), "<b>$registration_count</b>").")"; }
+      else
+	{ print " (".sprintf(_("%s registration pending"), "<b>$registration_count</b>").")"; }
       print $HTML->box_bottom();
       print '<br />';
     }
@@ -240,14 +257,19 @@ if($project->Uses("download")) {
   # the pointer is always the filelist, this page will handle redirect
   # appropriately in case that no download area is here
   print utils_link($project->getArtifactUrl("files"),
-		   html_image("download.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Filelist')).'&nbsp;'._("Filelist").' ('._("Download area").')');
+		   html_image("download.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Filelist')).'&nbsp;'._("Filelist (Download area)"));
   $i++;
 }
 
 # Memberlist
 specific_makesep();
 print utils_link($GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name,
-		 html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Memberlist')).'&nbsp;'._("Project Memberlist"));
+	 html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Memberlist')).'&nbsp;'._("Project Memberlist"));
+if ($membersnum[count] > 1) 
+{ print " (".sprintf(_("%s members"), "<b>$membersnum[count]</b>").")"; }
+else
+{ print " (".sprintf(_("%s member"), "<b>$membersnum[count]</b>").")"; }
+
 $i++;
 
 print $HTML->box_bottom();
@@ -288,10 +310,16 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
 
 	$res_count = db_query("SELECT count(*) AS count FROM support WHERE group_id=$group_id AND status_id != 3");
 	$row_count = db_fetch_array($res_count);
-	print " (<b>$row_count[count]</b>";
+
+
+	if ($row_count[count] > 1) 
+	  { print " (".sprintf(_("%s open requests"), "<b>$row_count[count]</b>"); }
+	else
+	  { print " (".sprintf(_("%s open request"), "<b>$row_count[count]</b>"); }
 	$res_count = db_query("SELECT count(*) AS count FROM support WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
-	print ' '._("open requests").", <b>$row_count[count]</b> "._("total").")\n";
+	print ', '.sprintf(_("%s total"), "<b>$row_count[count]</b>").")\n";
+
 	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Request"), 0, group_restrictions_check($group_id, "support"));
 	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Requests"));
       }
@@ -340,8 +368,12 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
       print utils_link($url,
 		       html_image("mail.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Mailing Lists"))).'&nbsp;'._("Mailing Lists"));
       $res_count = db_query("SELECT count(*) AS count FROM mail_group_list WHERE group_id=$group_id AND is_public=1");
-      $row_count = db_fetch_array($res_count);
-      print " (<b>$row_count[count]</b> "._("public mailing lists").")";
+      $row_count = db_fetch_array($res_count);	
+      if ($row_count[count] > 1) 
+	{ print " (".sprintf(_("%s public mailing-lists"), "<b>$row_count[count]</b>").")"; }
+      else
+	{ print " (".sprintf(_("%s public mailing-list"), "<b>$row_count[count]</b>").")"; }
+
       $i++;
     }
 
@@ -351,7 +383,13 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
     specific_makesep();
     print utils_link($GLOBALS['sys_home'].'people/?group='.$group_name,
 		     html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("People"))).'&nbsp;'._("This project is looking for people"));
-    print ' (<b>'.people_project_jobs_rows($group_id).'</b> '._("jobs").')';
+
+    $job_count = people_project_jobs_rows($group_id);
+
+    if ($job_count > 1) 
+      { print " (".sprintf(_("%s contributors wanted"), "<b>$job_count</b>").")"; }
+    else
+      { print " (".sprintf(_("%s contributor wanted"), "<b>$job_count</b>").")"; }
     $i++;
   }
 
@@ -380,7 +418,7 @@ if ($project->Uses("patch") ||
       $url = $project->getArtifactUrl("cvs");
       
       html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'CVS'));
-      print '&nbsp;<a href="'.$url.'">'._("CVS Repository").'</a>';
+      print '&nbsp;<a href="'.$url.'">'._("Source Code Manager: CVS Repository").'</a>';
 
       if ($project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '' && $project->Uses("cvs"))
 	{
@@ -405,16 +443,22 @@ if ($project->Uses("patch") ||
     $url = $project->getArtifactUrl("bugs");
 
     print utils_link($url,
-		     html_image("bug.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Bug Tracking"))).'&nbsp;'._("Bug Tracking"));
+		     html_image("bug.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Bug Tracking"))).'&nbsp;'._("Bug Tracker"));
     
     if (group_get_artifact_url("bugs", 0) == $url)
       {
+
 	$res_count = db_query("SELECT count(*) AS count FROM bugs WHERE group_id=$group_id AND status_id != 3");
 	$row_count = db_fetch_array($res_count);
-	print " (<b>$row_count[count]</b>";
+
+	if ($row_count[count] > 1) 
+	  { print " (".sprintf(_("%s open bugs"), "<b>$row_count[count]</b>"); }
+	else
+	  { print " (".sprintf(_("%s open bug"), "<b>$row_count[count]</b>"); }
 	$res_count = db_query("SELECT count(*) AS count FROM bugs WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
-	print ' '._("open bugs").", <b>$row_count[count]</b> "._("total").")\n";
+	print ', '.sprintf(_("%s total"), "<b>$row_count[count]</b>").")\n";
+
 	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Bug"), 0, group_restrictions_check($group_id, "bugs"));
 	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Bugs"));
       }
@@ -433,12 +477,17 @@ if ($project->Uses("patch") ||
 
     if (group_get_artifact_url("task", 0) == $url)
       {
+	
 	$res_count = db_query("SELECT count(*) AS count FROM task WHERE group_id=$group_id AND status_id != 3");
 	$row_count = db_fetch_array($res_count);
-	print " (<b>$row_count[count]</b>";
+	if ($row_count[count] > 1) 
+	  { print " (".sprintf(_("%s open tasks"), "<b>$row_count[count]</b>"); }
+	else
+	  { print " (".sprintf(_("%s open task"), "<b>$row_count[count]</b>"); }
 	$res_count = db_query("SELECT count(*) AS count FROM task WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
-	print ' '._("open tasks").", <b>$row_count[count]</b> "._("total").")\n";
+	print ', '.sprintf(_("%s total"), "<b>$row_count[count]</b>").")\n";
+
 	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Task"), 0, group_restrictions_check($group_id, "task"));
 	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Tasks"));
       }
@@ -460,10 +509,14 @@ if ($project->Uses("patch") ||
       {
 	$res_count = db_query("SELECT count(*) AS count FROM patch WHERE group_id=$group_id AND status_id != 3");
 	$row_count = db_fetch_array($res_count);
-	print " (<b>$row_count[count]</b>";
+	if ($row_count[count] > 1) 
+	  { print " (".sprintf(_("%s open patches"), "<b>$row_count[count]</b>"); }
+	else
+	  { print " (".sprintf(_("%s open patch"), "<b>$row_count[count]</b>"); }
 	$res_count = db_query("SELECT count(*) AS count FROM patch WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
-	print ' '._("open patch").", <b>$row_count[count]</b> "._("total").")\n";
+	print ', '.sprintf(_("%s total"), "<b>$row_count[count]</b>").")\n";
+
 	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Patch"), 0, group_restrictions_check($group_id, "patch"));
 	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Patches"));
       }
