@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.9 2004/09/22 08:11:51 yeupou Exp $
+# $Id: general.php,v 1.13 2004/11/24 09:19:47 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Stphane Urbanovski <s.urbanovski@ac-nancy-metz.fr>
 #                          Mathieu Roy <yeupou--at--gnu.org>
@@ -25,8 +25,12 @@
 function search_box ($searched_words='', $only_artifact=0, $size=15, $class="")
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':search_box ';
-  global $words,$forum_id,$group_id,$is_bug_page,$exact,$type_of_search,$type,$max_rows,$printer;
+  global $words,$forum_id,$group_id,$is_bug_page,$exact,$type_of_search,$type,$max_rows,$only_group_id;
 
+  if ($only_group_id)
+    { 
+      $group_id = $only_group_id;
+    }
 
   # if there is no search currently, set the default
   if (!isset($type_of_search))
@@ -61,13 +65,35 @@ function search_box ($searched_words='', $only_artifact=0, $size=15, $class="")
 
       print '<option value="people"'.(($type_of_search == "people") ? ' selected="selected"' : "").'>'._("People")."</option>\n";
 
-      print '<option value="support"'.(($type_of_search == "support") ? ' selected="selected"' : "").'>'._("Support")."</option>\n";
+      unset($text);
+      $group_realname = substr(group_getname($group_id), 0, 10)."...";
+      if (!$group_id)
+	{ $text = _("Support");	}
+      else
+	{ $text = sprintf(_("%s Support"), $group_realname); }
 
-      print '<option value="bugs"'.(($type_of_search == "bugs") ? ' selected="selected"' : "").'>'._("Bugs")."</option>\n";
+      print '<option value="support"'.(($type_of_search == "support") ? ' selected="selected"' : "").'>'.$text."</option>\n";
+      
+      if (!$group_id)
+	{ $text = _("Bugs");	}
+      else
+	{ $text = sprintf(_("%s Bugs"), $group_realname); }
 
-      print '<option value="task"'.(($type_of_search == "task") ? ' selected="selected"' : "").'>'._("Task")."</option>\n";
+      print '<option value="bugs"'.(($type_of_search == "bugs") ? ' selected="selected"' : "").'>'.$text."</option>\n";
+      
+      if (!$group_id)
+	{ $text = _("Tasks");	}
+      else
+	{ $text = sprintf(_("%s Tasks"), $group_realname); }
 
-      print '<option value="patch"'.(($type_of_search == "patch") ? ' selected="selected"' : "").'>'._("Patch")."</option>\n";
+      print '<option value="task"'.(($type_of_search == "task") ? ' selected="selected"' : "").'>'.$text."</option>\n";
+
+      if (!$group_id)
+	{ $text = _("Patchs");	}
+      else
+	{ $text = sprintf(_("%s Patchs"), $group_realname); }
+
+      print '<option value="patch"'.(($type_of_search == "patch") ? ' selected="selected"' : "").'>'.$text."</option>\n";
 
       if ($GLOBALS['sys_use_google'])
 	{
@@ -75,28 +101,27 @@ function search_box ($searched_words='', $only_artifact=0, $size=15, $class="")
 	}
 
       print '</select>';
-
+      
     }
   if ($size < 16)
     { print '<br />'; }
-
+  
   if (isset($group_id))
     {
-      print "<input type=\"hidden\" value=\"$group_id\" name=\"group_id\" />\n";
+      print "<input type=\"hidden\" value=\"$group_id\" name=\"only_group_id\" />\n";
     }
-  if (isset($printer))
-    {
-      print "<input type=\"hidden\" value=\"1\" name=\"printer\" />\n";
-    }
-
+  
   print ' <input type="submit" name="Search" value="'._("Search").'" />';
-
+  
   if ($size > 15)
     {
       print '<br />&nbsp;<input type="radio" name="exact" value="0"'.( $exact ? " " : " checked").' />'._("with at least one of the words")."\n";
       print '<br />&nbsp;<input type="radio" name="exact" value="1"'.( $exact ? " checked" : " " ).' />'._("with all of the words")."\n";
       print '<br />&nbsp;'.sprintf(_("%s results per page"), '<input type="text" name="max_rows" value="'.$max_rows.'" size="4" />')."\n";
 
+      
+  if (!isset($group_id))
+    {
       # add the functionality to restrict the search to a project type
       print "<br />&nbsp;";
       
@@ -107,16 +132,17 @@ function search_box ($searched_words='', $only_artifact=0, $size=15, $class="")
           $select .= '<option value="'.$eachtype['type_id'].'"'.($type == $eachtype['type_id'] ? ' selected="selected"' : '').'>'.$eachtype['name'].'</option>'."\n";
         }
       $select .= '</select>'."\n";
-
+      
       print sprintf(_("Search in %s group type, when searching for a \"Project/Group\"."), $select);
-
-      print '<p>'._("Note: You can use the wildcard *, standing for everything.").'</p>';
+    }
+  
+  print '<p>'._("Notes: You can use the wildcard *, standing for everything. You can also search items by number.").'</p>';
     }
   else
     {
       print '<input type="hidden" name="exact" value="1" />';
     }
-
+  
   if (!$dontclose) 
     { print '      </form>'; }
 }
@@ -124,7 +150,7 @@ function search_box ($searched_words='', $only_artifact=0, $size=15, $class="")
 function search_send_header ()
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':search_send_header () ';
-  global $HTML,$words,$type_of_search,$group_id,$printer;
+  global $HTML,$words,$type_of_search,$only_group_id;
 
   if ($type_of_search == "soft" || $type_of_search == "people")
     {
@@ -132,29 +158,15 @@ function search_send_header ()
       # group id is meaningless when looking for someone
       $group_id = 0;
     }
-
-  if (!$printer)
-    { site_header(array('title'=>_("Search"),'toptab'=>'search')); }
-  else
-    {
-
-      print '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
-"http://www.w3.org/TR/REC-html40/loose.dtd">
-
-<html>
-  <head>
-    <title>'._("Search").'</title>
-    <meta name="Generator" content="Savane, see http://gna.org/" />
-    <link rel="stylesheet" type="text/css" href="'.$GLOBALS['sys_home'].'css/'.SV_THEME.'.css">
-    <link rel="icon" type="image/png" href="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/icon.png">';
-
-    }
-  # Print the form
+  
+  site_header(array('title'=>_("Search"),'toptab'=>'search')); 
+  
+# Print the form
   print '<h3>';
-  if (!$group_id)
+  if (!$only_group_id)
     { print _("New search:"); }
   else
-    { printf(_("New search for the Group %s:"), group_getname($group_id)); }
+    { printf(_("New search for the Group %s:"), group_getname($only_group_id)); }
   print '</h3>';
   print "<div>";
   search_box($words, '', 45);
@@ -179,25 +191,20 @@ function search_send_header ()
       else if ($type_of_search == "people")
 	{ $type_of_search_real = _("People"); }
 
-      if (!$group_id)
+      if (!$only_group_id)
 	{
 	  printf(_("Search results for %s (in %s):"), '<font class="bold">'.$words.'</font>', $type_of_search_real);
 	}
       else
 	{
-	  printf(_("Search results for %s (in %s, for the Group %s):"), '<font class="bold">'.$words.'</font>', $type_of_search_real, group_getname($group_id));
+	  printf(_("Search results for %s (in %s, for the Group %s):"), '<font class="bold">'.$words.'</font>', $type_of_search_real, group_getname($only_group_id));
 	}
     }
-  else
+else
     { print _("Search results:"); }
 
   print '</h3>';
 
-
-  if (!$printer)
-    {
-      print '<p><a href="'.$GLOBALS['REQUEST_URI'].'&amp;printer=1"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/print.png" border="0" />'._('Printer version').'</a></p>';
-    }
 }
 
 
@@ -222,7 +229,7 @@ function search_failed ()
 function search_run ($words, $type_of_search="soft", $return_error_messages=1)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':search_run ($words, $type_of_search="soft", $return_error_messages=1) ';
-  global $type, $exact, $crit, $offset, $group_id, $search_without_group_id, $max_rows;
+  global $type, $exact, $crit, $offset, $only_group_id, $max_rows;
 
   # Remove useless blank spaces, escape nasty characters
   $words = trim($words);
@@ -252,6 +259,9 @@ function search_run ($words, $type_of_search="soft", $return_error_messages=1)
 
   # Accept only to do a search for more than 2 characters.
   # Exit only if we were not told to avoid returning error messages.
+  # Note: we tell user we want more than 3 characters, to incitate to
+  # do clever searchs. But it will be ok for only 2 characters (limit
+  # that conveniently allow us to search by items numbers)
   if ($words && (strlen($words) < 3) && $return_error_messages)
     {
       search_failed();
@@ -265,11 +275,17 @@ function search_run ($words, $type_of_search="soft", $return_error_messages=1)
       $words1 = implode($array,"%' $crit group_name LIKE '%");
       $words2 = implode($array,"%' $crit short_description LIKE '%");
       $words3 = implode($array,"%' $crit unix_group_name LIKE '%");
+      $words4=implode($array,"%' $crit group_id LIKE '%");
+      # remove # from words4
+      $words4=ereg_replace("#","",$words4);
     }
   else if ($type_of_search == "people")
     {
       $words1=implode($array,"%' $crit user_name LIKE '%");
       $words2=implode($array,"%' $crit realname LIKE '%");
+      $words3=implode($array,"%' $crit user_id LIKE '%");
+      # remove # from words3
+      $words3=ereg_replace("#","",$words3);
     }
   else if ($type_of_search == 'bugs' ||
 	   $type_of_search == 'support' ||
@@ -278,6 +294,9 @@ function search_run ($words, $type_of_search="soft", $return_error_messages=1)
     {
       $words1=implode($array,"%' $crit ".$type_of_search.".details LIKE '%");
       $words2=implode($array,"%' $crit ".$type_of_search.".summary LIKE '%");
+      $words3=implode($array,"%' $crit ".$type_of_search.".bug_id LIKE '%");
+      # remove # from words3
+      $words3=ereg_replace("#","",$words3);
     }
 
   # Build SQL command
@@ -288,21 +307,21 @@ function search_run ($words, $type_of_search="soft", $return_error_messages=1)
 	  $sql = "SELECT group_name,unix_group_name,type,group_id,short_description ".
 	     "FROM groups ".
 	     "WHERE status='A' AND is_public='1' ".
-	     "AND ((group_name LIKE '%$words1%') OR (short_description LIKE '%$words2%') OR (unix_group_name LIKE '%$words3%')) ORDER BY  unix_group_name,group_name LIMIT $offset,".($max_rows+1);
+	     "AND ((group_name LIKE '%$words1%') OR (short_description LIKE '%$words2%') OR (unix_group_name LIKE '%$words3%') OR (group_id LIKE '$words4')) ORDER BY  unix_group_name,group_name LIMIT $offset,".($max_rows+1);
 	}
       else
 	{
 	  $sql = "SELECT group_name,unix_group_name,type,group_id,short_description ".
 	     "FROM groups ".
 	     "WHERE status='A' AND type='$type' AND is_public='1' ".
-	     "AND ((group_name LIKE '%$words1%') OR (short_description LIKE '%$words2%') OR (unix_group_name LIKE '%$words3%')) ORDER BY unix_group_name,group_name LIMIT $offset,".($max_rows+1);
+	     "AND ((group_name LIKE '%$words1%') OR (short_description LIKE '%$words2%') OR (unix_group_name LIKE '%$words3%') OR (group_id LIKE '$words4')) ORDER BY unix_group_name,group_name LIMIT $offset,".($max_rows+1);
 	}
     }
   else if ($type_of_search == "people")
     {
       $sql = "SELECT user_name,user_id,realname "
 	 . "FROM user "
-	 . "WHERE ((user_name LIKE '%$words1%') OR (realname LIKE '%$words2%')) AND (status='A') ORDER BY user_name LIMIT $offset,".($max_rows+1);
+	 . "WHERE ((user_name LIKE '%$words1%') OR (realname LIKE '%$words2%') OR (user_id LIKE '$words3')) AND (status='A') ORDER BY user_name LIMIT $offset,".($max_rows+1);
     }
   else if ($type_of_search == 'bugs' ||
 	   $type_of_search == 'support' ||
@@ -310,11 +329,11 @@ function search_run ($words, $type_of_search="soft", $return_error_messages=1)
 	   $type_of_search == 'task')
     {
 
-      if ($group_id && !$search_without_group_id)
+      if ($only_group_id)
 	{
 	  # $search_without_group_id can be set to avoid restricting search
 	  # to a group even if group_id is set
-	  $sql_with_group_id = "AND ".$type_of_search.".group_id='$group_id' ";
+	  $sql_with_group_id = "AND ".$type_of_search.".group_id='$only_group_id' ";
 	}
 
       $sql = "SELECT ".$type_of_search.".bug_id,".
@@ -326,7 +345,8 @@ function search_run ($words, $type_of_search="soft", $return_error_messages=1)
 	 $type_of_search.".group_id "
 	 . "FROM ".$type_of_search.",user "
 	 . "WHERE user.user_id=".$type_of_search.".submitted_by AND ((".$type_of_search.".details LIKE '%$words1%') "
-	 . "OR (".$type_of_search.".summary LIKE '%$words2%')) "
+	 . "OR (".$type_of_search.".summary LIKE '%$words2%') "
+	 . "OR (".$type_of_search.".bug_id = '$words3')) "
 	 . $sql_with_group_id
 	 . "GROUP BY bug_id,summary,date,user_name "
 	 . "ORDER BY ".$type_of_search.".date DESC "
