@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: theme.php,v 1.9 2004/09/22 08:11:51 yeupou Exp $
+# $Id: theme.php,v 1.11 2004/11/22 09:12:49 yeupou Exp $
 #
 #  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -63,8 +63,8 @@ function theme_list ($strict=0)
       # take only correct css files
       if (preg_match("/^(.*)\.css$/", $file, $matches)) 
 	{
-	  # base.css is always ignored
-	  if ($matches[1] != "base") {
+	  # base.css and printer.css are always ignored
+	  if ($matches[1] != "base" && $matches[1] != "printer") {
 	    if (!$strict)
 	      {
 		$theme[] = $matches[1];
@@ -89,6 +89,15 @@ function theme_list ($strict=0)
 }
 
 
+
+##### THEME SELECTION
+## First check if the printer mode is asked. If not, proceed to the usual
+## theme selection
+if ($_GET["printer"] == 1) {
+  define('SV_THEME', "printer");
+  return true;
+}
+
 if (isset($HTTP_COOKIE_VARS["SV_THEME"])) 
 {
   # the user selected a theme
