@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php,v 1.17 2004/09/23 16:16:40 yeupou Exp $
+# $Id: data.php,v 1.22 2004/11/29 07:36:15 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -133,6 +133,7 @@ function &trackers_data_get_notification_settings($group_id, $tracker_name)
   $settings['glnotif'] = db_result($result,0,$tracker_name."_glnotif");
   $settings['glsendall'] = db_result($result,0,"send_all_".$tracker_name);
   $settings['glnewad'] = db_result($result,0,"new_".$tracker_name."_address");
+  $settings['private_exclude'] = db_result($result,0,$tracker_name."_private_exclude_address");
 
   $cat_field_name = "category_id";
   # Warning: The hardcoded fiels names: bug_fv_id and bug_field_id will need to be changed
@@ -197,20 +198,19 @@ function trackers_data_show_notification_settings($group_id, $tracker_name, $sho
 	  <INPUT TYPE="RADIO" NAME="'.$tracker_name.'_notif_scope" VALUE="both" '.$bothradio.' />&nbsp;&nbsp;<span class="preinput">'._("Notify persons in the category related list in addition to the global list").'</span><br />
 
 
-	  <h5>'._("Category related lists").'</h5>';
+	  <h3>'._("Category related lists").'</h3>';
 	print '<INPUT TYPE="HIDDEN" NAME="'.$tracker_name.'_nb_categories" VALUE="'.$grtrsettings['nb_categories'].'" />';
 
 	for ($i=0; $i < $grtrsettings['nb_categories'] ; $i++) 
 	  {
 	    print '<INPUT TYPE="HIDDEN" NAME="'.$tracker_name.'_cat_'.$i.'_bug_fv_id" VALUE="'.$grtrsettings['category'][$i]['fv_id'].'" />';
-	    print '<span class="preinput">'.$grtrsettings['category'][$i]['name'].'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_cat_'.$i.'_email" VALUE="'.$grtrsettings['category'][$i]['email'].'" SIZE="30" MAXLENGTH="255" /><br />
-
-          <span class="preinput">'._("Send on all updates:").'</span>&nbsp;&nbsp;
-	  <INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_cat_'.$i.'_send_all_flag" VALUE="1" '. (($grtrsettings['category'][$i]['send_all_flag'])?'checked="checked"':'') .' /><br />
+	    print '<span class="preinput">'.$grtrsettings['category'][$i]['name'].'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_cat_'.$i.'_email" VALUE="'.$grtrsettings['category'][$i]['email'].'" SIZE="50" MAXLENGTH="255" />
+          &nbsp;&nbsp;<span class="preinput">(
+	  <INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_cat_'.$i.'_send_all_flag" VALUE="1" '. (($grtrsettings['category'][$i]['send_all_flag'])?'checked="checked"':'') .' />'._("Send on all updates").')</span><br />
 ';
 	  }
 
-	print '<h5>'._("Global list").'</h5>';
+	print '<h3>'._("Global list").'</h3>';
 
       } else {
 	if ($show_intro_msg != 0) {
@@ -220,9 +220,18 @@ function trackers_data_show_notification_settings($group_id, $tracker_name, $sho
 	  the corresponding email addresses (comma separated list)."), $tracker_name).'<br /><br />';
 	}
       }
-      print '<span class="preinput">'._("Carbon-Copy List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_new_item_address" VALUE="'.$grtrsettings['glnewad'].'" SIZE="40" MAXLENGTH="255"><br />
-      <span class="preinput">'._("Send on all updates:").'</span>&nbsp;&nbsp;<INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_send_all_changes" VALUE="1" '. (($grtrsettings['glsendall'])?'CHECKED':'') .'>';
-   }
+      print '<span class="preinput">'._("Global List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_new_item_address" VALUE="'.$grtrsettings['glnewad'].'" SIZE="50" MAXLENGTH="255" />
+      &nbsp;&nbsp;<span class="preinput">(<INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_send_all_changes" VALUE="1" '. (($grtrsettings['glsendall'])?'CHECKED':'') .'>'._("Send on all updates").')</span>';
+
+	print '<h3>'._("Private items exclude list").'</h3>';
+	if ($show_intro_msg != 0) {
+	  print '
+	  '._("Addresses registered in this list will be excluded from default mail notification for private items.").'<br /><br />';
+	}
+	
+	print '<span class="preinput">'._("Exclude List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_private_exclude_address" VALUE="'.$grtrsettings['private_exclude'].'" SIZE="50" MAXLENGTH="255" /><br />'; 
+      
+    }
 }
 
 function trackers_data_post_notification_settings($group_id, $tracker_name)
@@ -243,6 +252,8 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
   $send_all_changes = $GLOBALS[$send_all_changes_name];
   $nb_categories_name = $tracker_name."_nb_categories";
   $nb_categories = $GLOBALS[$nb_categories_name];
+  $private_exclude_address_name = $tracker_name."_private_exclude_address";
+  $private_exclude_address = $GLOBALS[$private_exclude_address_name];
 
   if ($notif_scope != "global") {
     if ($notif_scope == "category") {
@@ -254,12 +265,13 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
   } else {
     $notif_value = 1;
   }
-
+  
   # set global notification info for this group
   $res_gl=db_query("UPDATE groups SET "
 	.$tracker_name."_glnotif='$notif_value', "
 	."send_all_".$tracker_name."='$send_all_changes', "
-	."new_".$tracker_name."_address=".($new_item_address? "'$new_item_address' " : "''")
+	."new_".$tracker_name."_address=".($new_item_address? "'$new_item_address' " : "''").", "
+	.$private_exclude_address_name.'='.($private_exclude_address? "'$private_exclude_address' " : "''")
 	. " WHERE group_id=$group_id");
   if (!$res_gl)
     { $local_feedback .= _("groups table Update failed.").' '.db_error(); }
@@ -660,8 +672,9 @@ function trackers_data_is_project_scope($field, $by_field_id=false)
 
 function trackers_data_is_status_closed($status)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_is_status_closed($status)';
-  return (($status == '3') || ($status == '10') );
+  if ($status == '3')
+    { return 1; }
+  return 0;
 }
 
 function trackers_data_get_field_name($field_id)
@@ -1169,11 +1182,12 @@ function trackers_data_update_usage($field_name,
   #    }
 
   # See if this field usage exists in the table for this project
-  $sql = 'SELECT bug_field_id FROM bug_field_usage '.
+  $sql = 'SELECT bug_field_id FROM '.ARTIFACT.'_field_usage '.
      "WHERE bug_field_id='$field_id' AND group_id='$group_id'";
   $result = db_query($sql);
   $rows = db_numrows($result);
 
+  fb($sql.$rows);
   # if it does exist then update it else insert a new usage entry for this field.
   if ($rows)
     {
@@ -1244,6 +1258,13 @@ function trackers_data_get_technicians ($group_id)
   return db_query($sql);
 }
 
+# Get transitions valid for a given tracker as an array
+# DEPRECATED, moved to transition.php
+function trackers_data_get_transition ($group_id)
+{
+  return trackers_transition_get_update($group_id);
+}
+
 function trackers_data_get_submitters ($group_id=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_get_submitters ($group_id=false)';
@@ -1293,9 +1314,15 @@ function trackers_data_get_valid_bugs ($group_id=false,$item_id='')
      "AND bug_id <> '$item_id' AND ".ARTIFACT.".resolution_id <> '2' ORDER BY bug_id DESC LIMIT 200";
   return db_query($sql);
 }
-function trackers_data_get_followups ($item_id=false)
+
+function trackers_data_get_followups ($item_id=false, $rorder=true)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_get_followups ($item_id=false)';
+  if ($rorder == "true") 
+    { $rorder = "DESC"; }
+  else 
+    { $rorder = "ASC"; }
+
   $sql="SELECT DISTINCT ".ARTIFACT."_history.bug_history_id,".ARTIFACT."_history.field_name,".ARTIFACT."_history.old_value,".ARTIFACT."_history.date,user.user_name,user.realname,".ARTIFACT."_field_value.value AS comment_type ".
      "FROM ".ARTIFACT."_history,".ARTIFACT."_field_value,".ARTIFACT."_field,".ARTIFACT.",user ".
      "WHERE ".ARTIFACT."_history.bug_id='$item_id' ".
@@ -1306,7 +1333,7 @@ function trackers_data_get_followups ($item_id=false)
      "AND ".ARTIFACT."_field_value.bug_field_id = ".ARTIFACT."_field.bug_field_id ".
      "AND (".ARTIFACT."_field_value.group_id = ".ARTIFACT.".group_id OR ".ARTIFACT."_field_value.group_id = '100') ".
      "AND  ".ARTIFACT."_field.field_name = 'comment_type_id' ".
-     "ORDER BY ".ARTIFACT."_history.date DESC";
+     "ORDER BY ".ARTIFACT."_history.date $rorder";
 
   return db_query($sql);
 }
@@ -1443,37 +1470,26 @@ function trackers_data_handle_update ($group_id,
       dbg("no management/techn. rights");
       exit_permission_denied();
     }
+
+  # DEPRECATED: the form_id method should make this useless, see
+  #    task #1049 for more details
+  # Check whether this is not a duplicate. This test is clumsy, to avoid
+  # overcomplication, it just make sure the comment is not exactly the
+  # same as the previous one posted for the item.
+  #$previous_comment = db_result(db_query("SELECT old_value FROM ".ARTIFACT."_history WHERE field_name='details' AND bug_id='$item_id' ORDER BY bug_history_id DESC LIMIT 1"), 0, 'old_value');
+  #dbg("PREV: ".$previous_comment." CURRENT: ".$vfl['details']);
+  #if ($vfl['details'] != '' && stripslashes($vfl['details']) == $previous_comment)
+  #  {
+  #    exit_error(_("Duplicate post: the previous comment posted on this item got exactly the same content."));
+  #  }
+
   
-  # Extract field transitions possibilities
+  # Extract field transitions possibilities:
   $field_transition = array();
-  $field_transition_sql = "SELECT field_id,from_value_id,to_value_id,is_allowed,assign_to,notification_list ".
-     "FROM trackers_field_transition ".
-     "WHERE group_id='".$group_id."' AND artifact='".ARTIFACT."' ";
-  
-  $field_transition_result = db_query($field_transition_sql);
-  if ($field_transition_result && db_numrows($field_transition_result) > 0) 
-    {
-      while ($this_transition = db_fetch_array($field_transition_result)) 
-	{
-	  $field_id = $this_transition['field_id'];
-	  if (!array_key_exists($field_id, $field_transition)) 
-	    { $field_transition[$field_id] = array(); }
-	  
-	  $from = $this_transition['from_value_id'];
-	  if ($from == "0")
-	    { $from = "any"; }
-	  if (!array_key_exists($from, $field_transition[$field_id])) 
-	    { $field_transition[$field_id][$from] = array(); }
-	  
-	  $to = $this_transition['to_value_id'];
-	  if (!array_key_exists($to, $field_transition[$field_id][$from])) 
-	    { $field_transition[$field_id][$from][$to] = array();  }
-	  
-	  $field_transition[$field_id][$from][$to]['allowed'] = $this_transition['is_allowed'];
-	  $field_transition[$field_id][$from][$to]['assign_to'] = $this_transition['assign_to'];
-	  $field_transition[$field_id][$from][$to]['notification_list'] = $this_transition['notification_list'];
-	}
-    }
+  $field_transition = trackers_data_get_transition($group_id);
+  # We will store in an array the transition_id accepted, to check
+  # other fields updates
+  $field_transition_accepted = array();
   
   # See which fields changed during the modification
   # and if we must keep history then do it. Also add them to the update
@@ -1489,33 +1505,46 @@ function trackers_data_handle_update ($group_id,
 
       $old_value = db_result($result,0,$field);
 
-      # handle field transitions checks/changes
+      # Handle field transitions checks+cc notif,
+      # register id of transition to execute
       # yeupou--gnu.org 2004-09-12: where the hell $by_field_id is set???
       $field_id = ($by_field_id ? $field : trackers_data_get_field_id($field));
       $field_transition_cc = '';
       if (array_key_exists($field_id, $field_transition)) 
 	{
           # First check basic transition
-	  # And check multiple transition, override other transition
+          # And check multiple transition, override other transition
 	  if (array_key_exists($old_value, $field_transition[$field_id])||
 	      array_key_exists("any", $field_transition[$field_id])) 
 	    {
 	      if (array_key_exists("any", $field_transition[$field_id]) && array_key_exists($value, $field_transition[$field_id]["any"]))
 		{
 		  $field_transition_cc = $field_transition[$field_id]["any"][$value]['notification_list'];
-		  if ($field_transition[$field_id]["any"][$value]['assign_to'] != 100)
-		    {
-		      $transition_assigned_to = $field_transition[$field_id]["any"][$value]['assign_to'];
-		    }
+		  
+		  # Register the transition, but only if the field it is about
+                  # was not filled in the form
+		  if (!is_array($changes[$field]) ||
+		      (!array_key_exists('del', $changes[$field]) &&
+		      !array_key_exists('add', $changes[$field])))
+		    {		  
+
+		      $field_transition_id = $field_transition[$field_id]["any"][$value]['transition_id'];
+		    }		  
 		}
 	      else if (array_key_exists($old_value, $field_transition[$field_id]) && array_key_exists($value, $field_transition[$field_id][$old_value])) 
 		{
 		  
 		  $field_transition_cc = $field_transition[$field_id][$old_value][$value]['notification_list'];
-		  if ($field_transition[$field_id][$old_value][$value]['assign_to'] != 100)
+		  
+                  # Register the transition, but only if the field it is about
+                  # was not filled in the form
+		  if (!is_array($changes[$field]) ||
+		      (!array_key_exists('del', $changes[$field]) &&
+		       !array_key_exists('add', $changes[$field])))
 		    {
-		      $transition_assigned_to = $field_transition[$field_id][$old_value][$value]['assign_to'];
+		      $field_transition_id = $field_transition[$field_id][$old_value][$value]['transition_id'];
 		    }
+
 		}
 		  
 	    }
@@ -1538,14 +1567,7 @@ function trackers_data_handle_update ($group_id,
 	}
 
       if ($differ)
-	{
-          # if assigned_to is the current field and differ, it must override
-          # transition motivated changes of assign_to
-          if ($field == 'assigned_to') 
-            {
-              $isset_assigned_to = true; 
-            }
-          
+	{          
 
           if ((trim($extra_addresses) != "") && (trim($field_transition_cc) != "")) 
             {
@@ -1574,43 +1596,58 @@ function trackers_data_handle_update ($group_id,
 	     trackers_field_display($field,$group_id,$old_value,false,false,true,true);
 	  $changes[$field]['add']=
 	     trackers_field_display($field,$group_id,$value,false,false,true,true);
+
+          # Register transition id 
+	  $field_transition_accepted[] = $field_transition_id;
+
 	}
     }
 
-  # Assigned_to is handled is a specific way if the change  is due to
-  # transitions: it won't override what was filled in the form.
-  # yeupou--gnu.org 2004-09-16: there's still a pending question: what happens
-  # if two contradictory orders are given, for instance if two fields changes
-  # require reassignation? Well, for now, let's assume that project admins
-  # will be clever enough.
-  if (!$isset_assigned_to && $transition_assigned_to != 0)
-    { 
-      $upd_list .= "assigned_to='$transition_assigned_to',";
-      trackers_data_add_history('assigned_to',$old_value = db_result($result,0,'assigned_to'),$transition_assigned_to,$item_id);
-    }
+  # Now we run transitions other fields update. This function does check
+  # what already changed and that we wont automatically update
+  trackers_transition_update_item($item_id, $field_transition_accepted, $changes);
 
   # Details field history is handled a little differently. Followup comments
   # are added in the bug history along with the comment type.
-  #
-  # If a canned response is given it overrides anything typed in the followup
-  # comment text area (aka details area).
-  # yeupou--gnu.org 2004-09-19: this behavior is more than questionnable.
   $details = $vfl['details'];
   if ($canned_response != 100)
     {
-      $sql="SELECT * FROM ".ARTIFACT."_canned_responses WHERE bug_canned_id='$canned_response'";
-      $res3=db_query($sql);
+      if ($details) 
+        {
+          # Add a separator between user sbumitted comment and canned 
+          # response
+          $details .= "\n\n";
+        }
+      
+      # Make sure we have an array even for a unique answer
+      if (!is_array($canned_response))
+        {
+          $tempvalue = $canned_response; 
+          $canned_response = array();
+	  $canned_response[] = $tempvalue; 
+          unset($tempvalue);
+        }
 
-      if ($res3 && db_numrows($res3) > 0)
-	{
-	  $details = addslashes(utils_unconvert_htmlspecialchars(db_result($res3,0,'body')));
-	  fb(_("Canned response used"));
-	}
-      else
-	{
-	  fb(_("Unable to use canned response"), 0);
-	  db_error();
-	}
+      # Browse the canned responses
+      while (list(,$thiscanned) = each($canned_response))
+        {
+
+           $sql="SELECT * FROM ".ARTIFACT."_canned_responses WHERE bug_canned_id='".addslashes($thiscanned)."'";
+           $res3=db_query($sql);
+
+            if ($res3 && db_numrows($res3) > 0)
+              {
+                 # add a data separatot
+                 if ($details) 
+                   { $details .= "\n\n";  }
+                 $details .= addslashes(utils_unconvert_htmlspecialchars(db_result($res3,0,'body')));
+                 fb(_("Canned response used"));
+	      }
+            else
+	      {
+                 fb(_("Unable to use canned response"), 0);
+              }
+        }
     }
 
   # Details field history is handled a little differently. Followup comments
@@ -1674,8 +1711,7 @@ function trackers_data_handle_update ($group_id,
 
       $sql="UPDATE ".ARTIFACT." SET $upd_list ".
 	 " WHERE bug_id='$item_id' AND group_id='$group_id'";
-      dbg($sql);
-      $result=db_query($sql);
+      $result=db_affected_rows(db_query($sql));
     }
 
   if (!$result)
@@ -1739,6 +1775,7 @@ function trackers_data_reassign_item ($item_id,
 	  return 0;
 	}
 
+		# move item
       $result = db_query("INSERT INTO ".$reassign_change_artifact.
 			 " (group_id,status_id,date,severity,submitted_by,summary,details,priority,planned_starting_date,planned_close_date,percent_complete)".
 			 " VALUES ".
@@ -1764,6 +1801,7 @@ function trackers_data_reassign_item ($item_id,
 	  fb(_("New item created."));
 	}
 
+
       # Need to get the new item value
       $new_item_id =  mysql_insert_id();
 
@@ -1835,8 +1873,8 @@ function trackers_data_reassign_item ($item_id,
 						 $row_data[$l],
 						 false,
 						 true,
-						 true,
-						 false);
+						 true, #6
+						 true);
 	      $comment .= "<br />";
 	    }
 	}
@@ -1921,8 +1959,7 @@ function trackers_data_reassign_item ($item_id,
 	{
 	  fb(_("Original item is now closed."));
 	}
-
-    }
+}
 
 }
 
@@ -1952,77 +1989,131 @@ function trackers_data_update_dependent_items ($depends_on, $item_id, $artifact)
 				    0,0,1);
 	  trackers_data_add_history("Dependencies",
 				    "-",
-				    ARTIFACT." #".$item_od." is dependent",
+				    ARTIFACT." #".$item_id." is dependent",
 				    $depends_on,
 				    0,0,1);
 	}
     }
 }
 
-function trackers_data_create_item($group_id,$vfl)
+# yeupou--gnu.org 2004-11-10: this function should probably removed
+# and handle_update be used instead.
+function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_create_item($group_id,$vfl)';
 
   #we don't force them to be logged in to submit a bug
   if (!user_isloggedin())
-    {
-      $user=100;
-    }
+    { $user=100; }
   else
-    {
-      $user=user_getid();
-    }
+    { $user=user_getid(); }
 
-  # make sure  required fields are not empty
+  # make sure required fields are not empty
   if (trackers_check_empty_fields($vfl) == false)
-    {
-      exit_missing_param();
-    }
+    { exit_error("Exiting"); }
 
+
+  # DEPRECATED: the form_id method should make this useless, see
+  #    task #1049 for more details
   # first make sure this wasn't double-submitted
   # we look for a bug with the same summary and group_id
   # if we found one, we double check with details and submitted_by.
-  $is_duplicate = db_result(db_query("SELECT bug_id FROM ".ARTIFACT.
-				     " WHERE summary='".
-				     htmlspecialchars($vfl['summary']).
-				     "' AND group_id='".
-				     $group_id.
-				     "'"),
-			    0,
-			    'bug_id');
-
-  if ($is_duplicate)
-    {
-      $is_duplicate = db_result(db_query("SELECT bug_id FROM ".ARTIFACT.
-					 " WHERE bug_id='".
-					 $is_duplicate.
-					 "' AND details='".
-					 htmlspecialchars($vfl['details']).
-					 "' AND submitted_by='".
-					 $user.
-					 "'"),
-				0,
-				'bug_id');
-    }
-
-  if ($is_duplicate)
-    {
-      $ffeedback = ' '._("Error - Duplicated submission. This item already exists in our database.");
-      return;
-    }
+#   $is_duplicate = db_result(db_query("SELECT bug_id FROM ".ARTIFACT.
+# 				     " WHERE summary='".
+# 				     htmlspecialchars($vfl['summary']).
+# 				     "' AND group_id='".
+# 				     $group_id.
+# 				     "'"),
+# 			    0,
+# 			    'bug_id');
+#
+#   if ($is_duplicate)
+#     {
+#       $is_duplicate = db_result(db_query("SELECT bug_id FROM ".ARTIFACT.
+# 					 " WHERE bug_id='".
+# 					 $is_duplicate.
+# 					 "' AND details='".
+# 					 htmlspecialchars($vfl['details']).
+# 					 "' AND submitted_by='".
+# 					 $user.
+# 					 "'"),
+# 				0,
+# 				'bug_id');
+#     }
+#
+#   if ($is_duplicate)
+#     {
+#       exit_error(_("Error - Duplicated submission: this item already exists in our database."), 1);
+#     }
 
   # Finally, create the bug itself
   # Remark: this SQL query only sets up the values for fields used by
   # this project. For other unused fields we assume that the DB will set
   # up an appropriate default value (see bug table definition)
 
+  # Extract field transitions possibilities:
+  $field_transition = array();
+  $field_transition = trackers_data_get_transition($group_id);
+  # We will store in an array the transition_id accepted, to check
+  # other fields updates
+  $field_transition_accepted = array();
+  $changes = array();
+
   # build the variable list of fiels and values
   reset($vfl);
   while ( list($field,$value) = each($vfl))
     {
       if (trackers_data_is_special($field))
 	{ continue; }
-      $vfl_cols .= ','.$field;
+
+      # If value is the special string default, take the defaulf from the database
+      if ($value == "!unknown!")
+	{ continue; }
+      
+      # COPIED from handle_update transition code, with one exception:
+      # old_value is equal to "none".
+      # handle field transitions checks/changes
+      # yeupou--gnu.org 2004-09-12: where the hell $by_field_id is set???
+      $field_id = ($by_field_id ? $field : trackers_data_get_field_id($field));
+      $field_transition_cc = '';
+      if (array_key_exists($field_id, $field_transition)) 
+	{
+          # First check basic transition
+	  # And check multiple transition, override other transition
+	  if (array_key_exists("100", $field_transition[$field_id])||
+	      array_key_exists("any", $field_transition[$field_id])) 
+	    {
+	      if (array_key_exists("any", $field_transition[$field_id]) && array_key_exists($value, $field_transition[$field_id]["any"]))
+		{
+		  $field_transition_cc = $field_transition[$field_id]["any"][$value]['notification_list'];
+		  
+		  # Register the transition, but only if the field it is about
+                  # was not filled in the form
+		  if (!is_array($changes[$field]) ||
+		      (!array_key_exists('del', $changes[$field]) &&
+		      !array_key_exists('add', $changes[$field])))
+		    {		  
+
+		      $field_transition_id = $field_transition[$field_id]["any"][$value]['transition_id'];
+		    }	
+		}
+	      else if (array_key_exists("100", $field_transition[$field_id]) && array_key_exists($value, $field_transition[$field_id]["100"])) 
+		{
+		  
+		  $field_transition_cc = $field_transition[$field_id]["100"][$value]['notification_list'];
+                  # Register the transition, but only if the field it is about
+                  # was not filled in the form
+		  if (!is_array($changes[$field]) ||
+		      (!array_key_exists('del', $changes[$field]) &&
+		       !array_key_exists('add', $changes[$field])))
+		    {
+		      $field_transition_id = $field_transition[$field_id]["100"][$value]['transition_id'];
+		    }
+		}
+		  
+	    }
+	}
+
       if (trackers_data_is_text_area($field) ||
 	  trackers_data_is_text_field($field))
 	{
@@ -2033,9 +2124,22 @@ function trackers_data_create_item($group_id,$vfl)
 	  # if it's a date we must convert the format to unix time
 	  list($value,$ok) = utils_date_to_unixtime($value);
 	}
-      $vfl_values .= ',\''.$value.'\'';
-    }
 
+      $vfl_cols .= ','.$field;
+      $vfl_values .= ',\''.$value.'\'';
+
+      # Keep track of the change: 
+      $changes[$field]['del']=
+      trackers_field_display($field,$group_id,$old_value,false,false,true,true);
+      $changes[$field]['add']=
+      trackers_field_display($field,$group_id,$value,false,false,true,true);
+      # Register transition id 
+      $field_transition_accepted[] = $field_transition_id;
+
+       
+      if ($field_transition_cc) 
+        { $extra_addresses .= $field_transition_cc; }
+    }
 
   # Add all special fields that were not handled in the previous block
   $fixed_cols = 'close_date,group_id,status_id,submitted_by,date,summary,details';
@@ -2044,15 +2148,19 @@ function trackers_data_create_item($group_id,$vfl)
 
 
   $sql="INSERT INTO ".ARTIFACT." ($fixed_cols $vfl_cols) VALUES ($fixed_values $vfl_values)";
-  dbg("DBG - SQL insert bug: $sql");
   $result=db_query($sql);
   $item_id=db_insertid($result);
 
   if (!$item_id)
     {
-      $ffeedback = ' '._("INSERT new bug failed.").' '._("Report to the Administrator");
+      fb(_("INSERT new bug failed, Report to the Administrator"), 1);
     }
 
+
+  # Now we run transitions other fields update. This function does check
+  # what already changed and that we wont automatically update
+  trackers_transition_update_item($item_id, $field_transition_accepted, $changes);
+
   #now return the trackers_id
   return $item_id;
 }
@@ -2117,8 +2225,8 @@ function trackers_data_get_canned_responses ($group_id)
   /*
       Show defined and site-wide responses
   */
-  $sql="SELECT bug_canned_id,title,body FROM ".ARTIFACT."_canned_responses WHERE ".
-     "(group_id='$group_id' OR group_id='0')";
+  $sql="SELECT bug_canned_id,title,body,order_id FROM ".ARTIFACT."_canned_responses WHERE ".
+     "(group_id='$group_id' OR group_id='0') ORDER BY order_id ASC";
 
   # return handle for use by select box
   return db_query($sql);
@@ -2296,3 +2404,11 @@ function trackers_data_delete_file($group_id, $item_id, $item_file_id)
 
 }
 
+
+
+function trackers_data_count_field_value_usage ($group_id, $field, $field_value_value_id)
+{
+  return db_numrows(db_query("SELECT bug_id FROM ".ARTIFACT." WHERE $field='$field_value_value_id' AND group_id='$group_id'"));
+}
+
+?>
\ No newline at end of file
