@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.11 2004/09/24 07:37:35 yeupou Exp $
+# $Id: general.php,v 1.13 2004/11/24 09:44:42 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -176,29 +176,39 @@ function trackers_list_all_fields($sort_func=false,$by_field_id=false)
 function trackers_field_label_display($field_name, $group_id,$break=false,$ascii=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_label_display($field_name, $group_id,$break=false,$ascii=false)';
-  $output = trackers_data_get_label($field_name).': ';
+  $label = trackers_data_get_label($field_name).':';
 
   if (!$ascii) 
-    { $output = '<font class="preinput"><font class="help" title="'.trackers_data_get_description($field_name).'">'.$output.'</font></font>'; }
+    { $output = '<font class="preinput"><font class="help" title="'.trackers_data_get_description($field_name).'">'.$label.'</font></font>'; }
+
   if ($break) 
     { $output .= ($ascii?"\n":'<br />'); }
   else
-    { $output .= ($ascii? ' ':'&nbsp;'); }
+    { 
+      if (!$ascii)
+        { $output .= '&nbsp;'; }
+      else
+        {
+          $output .= sprintf("%25s", $label).' ';
+        }
+     }
+
   return $output;
 }
 
 function trackers_field_display ($field_name, 
 				 $group_id, 
 				 $value='xyxy',
-				 $break=false, 
+				 $break=false, #4
 				 $label=true, 
-				 $ro=false, 
+				 $ro=false, #6
 				 $ascii=false, 
-				 $show_none=false, 
+				 $show_none=false, #8 
 				 $text_none='None',
-				 $show_any=false, 
+				 $show_any=false, #10
 				 $text_any='Any',
-                                 $allowed_transition_only=false)
+                                 $allowed_transition_only=false, #12
+                                 $show_unknown=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_display  ';			
   /*
@@ -270,9 +280,16 @@ function trackers_field_display ($field_name,
 	    }
 	  else
 	    {
-	      $output .= trackers_field_box($field_name,'',$group_id, $value,
-					    $show_none,$text_none,$show_any,
-					    $text_any, $allowed_transition_only);
+	      $output .= trackers_field_box($field_name,
+					    '',
+					    $group_id,
+					    $value, #4
+					    $show_none,
+					    $text_none,
+					    $show_any,
+					    $text_any, #8
+					    $allowed_transition_only,
+					    $show_unknown);
 	    }
 	}
       break; 
@@ -425,16 +442,24 @@ function trackers_field_textarea($field_name,$value='',$cols=0,$rows=0)
 
 }
 
-function trackers_field_box($field_name,$box_name='',$group_id,$checked=false,$show_none=false,$text_none='None',$show_any=false, $text_any='Any', $allowed_transition_only=false)
+function trackers_field_box ($field_name,
+			     $box_name='',
+			     $group_id,
+			     $checked=false, #4
+			     $show_none=false,
+			     $text_none='None',
+			     $show_any=false, 
+			     $text_any='Any', #8
+			     $allowed_transition_only=false,
+			     $show_unknown=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_box ';
 
   # Returns a select box populated with field values for this project
   # if box_name is given then impose this name in the select box
   # of the  HTML form otherwise use the field_name
-
   if (!$group_id)
-    { return 'ERROR - no group_id'; }
+    { return _('Error: no group defined'); }
   else
     {
       $result = trackers_data_get_field_predefined_values($field_name,$group_id,$checked);
@@ -451,7 +476,7 @@ function trackers_field_box($field_name,$box_name='',$group_id,$checked=false,$s
 	  $default_auth = db_result(db_query("SELECT transition_default_auth ".
 					     "FROM ".ARTIFACT."_field_usage ".
 					     "WHERE group_id='$group_id' AND bug_field_id='$field_id'"), 0, 'transition_default_auth');
-	  # avoid corrupted database content, if it's not F, it must be A.
+	  # avoid corrupted database content, if its not F, it must be A.
 	  if ($default_auth != "F")
 	    { $default_auth = "A"; }
 	  
@@ -495,14 +520,23 @@ function trackers_field_box($field_name,$box_name='',$group_id,$checked=false,$s
 		  }
  
                 # always add the any values cases
-		return html_build_select_box_from_arrays (array_keys($val_label),array_values($val_label),$box_name,$checked,$show_none,$text_none,$show_any, $text_any);
+		return html_build_select_box_from_arrays(array_keys($val_label),
+							 array_values($val_label),
+							 $box_name,
+							 $checked, #4
+							 $show_none,
+							 $text_none, #6
+							 $show_any, 
+							 $text_any, #8
+							 $show_unknown);
           }
         }
       } 
       
 # if no transition defined use 'normal' code
       
-      return html_build_select_box ($result,$box_name,$checked,$show_none,$text_none,$show_any, $text_any);
+      return html_build_select_box ($result,$box_name,$checked,$show_none,$text_none,$show_any, $text_any,$show_unknown);
+
     }
 }
 
@@ -620,8 +654,6 @@ function trackers_check_empty_fields($field_array)
       Params:
       field_array: associative array of field_name -> value
   */
-  global $feedback, $ffeedback;
-
   $bad_fields = array();
   reset($field_array);
   while ( list($key, $val) = each($field_array))
@@ -641,7 +673,7 @@ function trackers_check_empty_fields($field_array)
 
   if (count($bad_fields) > 0)
     {
-      $ffeedback = sprintf(_("Missing field(s): %s. Empty values for the above listed field(s) are not allowed. Click on the \"Back\" button of your browser and try again."), join(', ',$bad_fields));
+      fb(sprintf(_("Missing field(s): %s. Empty values for the above listed field(s) are not allowed. Click on the \"Back\" button of your browser and try again."), join(', ',$bad_fields)), 1);
 
       return false;
     }
@@ -657,12 +689,35 @@ function trackers_canned_response_box ($group_id,$name='canned_response')
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_canned_response_box ';
   if (!$group_id)
     {
-      return 'ERROR - No group_id';
+      fb(_("Error, no group_id"),1);
+      return 0;
     }
   else
     {
-      $result=trackers_data_get_canned_responses($group_id);
-      return html_build_select_box ($result,$name);
+      $vals = array();
+      $texts = array();
+      $result = trackers_data_get_canned_responses($group_id);
+      if (db_numrows($result) > 0) 
+	{
+	  if (db_numrows($result) > 1) 
+	    {
+	      $vals[] = '!multiple!';
+	      $texts[] = "> "._("Multiple Canned Responses");
+	    }
+
+	  while ($entry = db_fetch_array($result))
+	    {
+	      $vals[] = $entry['bug_canned_id'];
+	      $texts[] = $entry['title'];
+	      
+	    }
+
+	  return html_build_select_box_from_arrays($vals, $texts ,$name);
+	}
+      else
+	{
+	  return form_input("hidden", "canned_response", "100")._("No canned response available");	  
+	}
     }
 }
 
@@ -956,10 +1011,10 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 
 }
 
-function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
+function trackers_mail_followup($item_id,$more_addresses=false,$changes=false,$force_exclude_list=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_mail_followup($item_id,$more_addresses=false,$changes=false)';
-  global $sys_datefmt,$feedback,$ffeedback;
+  global $sys_datefmt;
 
   $sql="SELECT * from ".ARTIFACT." WHERE bug_id='$item_id'";
 
@@ -967,27 +1022,31 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
   $bug_href = "http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home'].ARTIFACT."/?func=detailitem&item_id=$item_id";
 
   if ($result && db_numrows($result) > 0)
-    {
-			
-      $group_id = db_result($result,0,'group_id');
- 
-      $body = "This mail is an automated notification from the ".ARTIFACT." tracker\n of the project: ".group_getname($group_id).".";
+  {
 
+  $group_id = db_result($result,0,'group_id');
+ 
+  # CONTENT OF THE MAIL MUST NOT BE TRANSLATED
+
+  $body = "This is an automated notification sent by ".$GLOBALS['sys_name']. ".
+It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_id)."\n";
       
       if ($changes)
 	{
-	  $body .= "\n\n/**************************************************************************/\n";
-	  $body .= "[".ARTIFACT." #".$item_id."] Latest Modifications:\n\n".
-	     format_item_changes($changes)."\n\n";
+	  $body .= "\n==============================================================================\n";
+	  $body .= " LATEST MODIFICATIONS of ".ARTIFACT." #".$item_id.":\n";
+          $body .= "==============================================================================\n\n".
+	     format_item_changes($changes)."\n";
 	}
 
-      $body .= "\n\n\n\n\n/**************************************************************************/\n";
-      $body .= "[".ARTIFACT." #".$item_id."] Full Item Snapshot:\n\n";
- 
-      $body .= "URL: <".$bug_href.">\n";
-      $body .= "Project: ".group_getname($group_id)."\n";
-      $body .= "Submitted by: ".user_getrealname(db_result($result,0,'submitted_by'))."\n";      
-      $body .= "On: ".format_date($sys_datefmt,db_result($result,0,'date'))."\n\n";
+      $body .= "\n==============================================================================\n";
+      $body .= " OVERVIEW of ".ARTIFACT." #".$item_id.":\n";
+      $body .= "==============================================================================\n\n";
+      $body .= "URL:\n  <".$bug_href.">\n\n";
+      $body .= trackers_field_display('summary', $group_id, db_result($result,0,'summary'),false,true,true,true)."\n";
+      $body .= sprintf("%25s", "Project:").' '.group_getname($group_id)."\n";
+      $body .= trackers_field_display('submitted_by', $group_id, db_result($result,0,'submitted_by'),false,true,true,true)."\n";
+      $body .= trackers_field_display('date', $group_id, db_result($result,0,'date'),false,true,true,true)."\n";
       
       # All other regular fields now		 
       $i=0;
@@ -1015,14 +1074,10 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
       $body .= "\n";
 						   
       # Now display other special fields
-      # Summary first. It is a special field because it is both
-      # displayed in the
-      # title of the bug form and here as a text field
-
-      $body .= "\n".trackers_field_display('summary', $group_id,
-					   db_result($result,0,'summary'),false,true,true,true).
-	 "\n\n".trackers_field_display('details', $group_id,
-				       db_result($result,0,'details'),false,true,true,true);
+      $body .= "    _______________________________________________________\n\n".trackers_field_display('details', 
+	                               $group_id,
+				       db_result($result,0,'details'),
+                                       true,true,true,true);
 
       # Then output the history of bug details from newest to oldest
       $body .= "\n\n".format_item_details($item_id, $group_id, true);
@@ -1034,8 +1089,9 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
       $body .= "\n\n".format_item_attached_files($item_id, $group_id, true);
 
       # Finally output the message trailer
-      $body .= "\n\n\n\n\n\nFor detailed info, follow this link:";
-      $body .= "\n<".$bug_href.">";
+      $body .= "\n==============================================================================\n\n";
+      $body .= "This item URL is:";
+      $body .= "\n  <".$bug_href.">";
 
 
       # See who is going to receive the notification.
@@ -1049,10 +1105,25 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
       if ($more_addresses)
 	{
 	  $to .= ($to ? ',':'').$more_addresses;
-	}	
+	}
 
-      sendmail_mail($from, $to, $subject, $body, group_getunixname($group_id), ARTIFACT, $item_id);
+      # If the item is private, take into account the exclude-list
+      if (db_result($result,0,'privacy') == '2')
+        {
+           $exclude_list = db_result(db_query("SELECT ".ARTIFACT."_private_exclude_address FROM groups WHERE group_id='$group_id'"),0, ARTIFACT."_private_exclude_address");
 
+        }
+
+      # Disallow mail notification for an address, private or not
+      if ($force_exclude_list)
+      {
+        if ($exclude_list) 
+          { $exclude_list .= ",".$force_exclude_list; }
+        else
+          { $exclude_list = $force_exclude_list; }
+      }
+
+      sendmail_mail($from, $to, $subject, $body, group_getunixname($group_id), ARTIFACT, $item_id, 0, 0, $exclude_list);
       # Useless feedback, already added by sendmail_mail()
       #fb(_("Item update sent.")); 
 
@@ -1067,10 +1138,11 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
 function trackers_attach_file($item_id,
 			      $group_id,
 			      $input_file,
-			      $input_file_name,
+			      $input_file_name, # 4
 			      $input_file_type,
-			      $input_file_size,
-			      $file_description)
+			      $input_file_size, # 6
+                              $file_description,
+			      &$changes)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_attach_file($item_id,';			 
 
@@ -1415,9 +1487,9 @@ function trackers_build_match_expression($field, &$to_match)
   else if (preg_match('/int/i', $type))
     {
 
-      # If it is sourrounded by /.../ the assume a regexp
+      # If it is sourrounded by /.../ then assume a regexp
       # else assume an equality
-      if (preg_match('/\/(.*)\#', $to_match, $matches))
+      if (preg_match('/\/(.*)\#/', $to_match, $matches))
 	{
 	  $expr = "$field RLIKE '".$matches[1]."' ";
 	}
@@ -1524,4 +1596,29 @@ function trackers_delete_file($group_id=false,$item_id=false,$item_file_id=false
   return trackers_data_delete_file($group_id, $item_id, $item_file_id);
 }
 
+# register a msg id for an item update notification
+function trackers_register_msgid ($msgid, $artifact, $item_id)
+{
+  return db_affected_rows(db_query("INSERT INTO trackers_msgid (msg_id,artifact,item_id) VALUES ('$msgid','$artifact','$item_id')"));
+}
+
+# Get a list, separated  a msg id for an item update notification
+function trackers_get_msgid ($artifact, $item_id, $latest="")
+{
+  if ($latest)
+    { $latest = "ORDER BY id DESC LIMIT 1"; }
+  
+  $result = db_query("SELECT msg_id FROM trackers_msgid WHERE artifact='$artifact' AND item_id='$item_id' $latest");
+  unset($list);
+  while ($id = db_fetch_array($result))
+    {
+      if (isset($list))
+	{ $list .= " "; }
+      $list .= "<".$id['msg_id'].">";
+    }
+  return $list;
+}
+
+
+
 ?>
