@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: show.php,v 1.16 2004/09/22 08:11:51 yeupou Exp $
+# $Id: show.php,v 1.17 2004/11/22 08:25:50 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -26,7 +26,14 @@
 
 
 
-function show_item_list ($result,$offset,$total_rows,$field_arr,$title_arr,$width_arr,$url,$nolink)
+function show_item_list ($result,
+			 $offset,
+			 $total_rows,
+			 $field_arr, #4
+			 $title_arr,
+			 $width_arr,
+			 $url,
+			 $nolink=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_item_list ';	
   global $sys_datefmt,$group_id,$PHP_SELF,$chunksz;
@@ -80,7 +87,7 @@ function show_item_list ($result,$offset,$total_rows,$field_arr,$title_arr,$widt
   $nav_bar .= " &nbsp;  &nbsp; &nbsp; &nbsp; ".sprintf(_("Items %s to %s"), ($offset+1), ($offset_last+1))."  &nbsp; &nbsp; &nbsp; &nbsp; ";
 
 
-  # If all bugs on screen, no next/end pointer at all
+  # If all items are on screen, no next/end pointer at all
   # FIXME: it should not count private items
   if ($total_rows > $chunksz)
     {
@@ -122,7 +129,7 @@ function show_item_list ($result,$offset,$total_rows,$field_arr,$title_arr,$widt
       # Do not even show private item, apart to technician level members
       # and submitter
       if (db_result($result, $i, 'privacy') == "2" &&
-	  !member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') &&
+	  !member_check_private(0,$group_id) &&
 	  db_result($result,$i,'submitted_by') != user_getname()) 
 	{
 	  dbg("Private item.");
@@ -130,9 +137,16 @@ function show_item_list ($result,$offset,$total_rows,$field_arr,$title_arr,$widt
       else
 	{	   
 	  print '<tr class="'.utils_get_priority_color(db_result($result, $i, 'priority'), db_result($result, $i, 'status_id')).'">'."\n";
-	  
+	  $thisitem_id = db_result($result, $i, 'bug_id');
+
 	  for ($j=0; $j<$nb_of_fields; $j++)
 	    {
+	      # If we are in digest mode, add the digest checkbox 
+	      if ($field_arr[$j] == "digest")
+		{
+		  print '<td class="center">'.form_input("checkbox", "items_for_digest[]", $thisitem_id).'</td>';
+		  continue;
+		}
 	      
 	      $value = db_result($result, $i, $field_arr[$j]);
 	      if ($width_arr[$j])
@@ -165,7 +179,6 @@ function show_item_list ($result,$offset,$total_rows,$field_arr,$title_arr,$widt
 		      
 		      print '&nbsp;#'.$value .'</a></td>'."\n";
 
-		      $thisitem_id = $value;
 		    }
 
 		}
@@ -241,31 +254,65 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
       $title_arr[]=_("Changed By");
       $title_arr[]=_("Updated Field");
       $title_arr[]=_("Previous Value");
+      $title_arr[]="=>";
       $title_arr[]=_("Replaced By");
 
       print html_build_list_table_top ($title_arr);
-
+    
+      $j=0;
       for ($i=0; $i < $rows; $i++)
 	{
-	  $field = db_result($result, $i, 'field_name');
+          $field = db_result($result, $i, 'field_name');
+	  $field_label = trackers_data_get_label($field);
+          # if field_label is empty, no label was found, return as it is stored
+          if (!$field_label)
+            { $field_label = $field; }
+
 	  $value_id =  db_result($result, $i, 'old_value');
 	  $new_value_id =  db_result($result, $i, 'new_value');
 
-	  print "\n".'<tr class="'. utils_get_alt_row_color($i).'">';
+          $date = db_result($result, $i, 'date');
+          $user = db_result($result, $i, 'user_name');
+
+          # If the previous date and user are equal, do not print user
+          # and date
+          if ($date == $previous_date && $user == $previous_user)
+            {
+     	  print "\n".'<tr class="'. utils_get_alt_row_color($j).'"><td>&nbsp;</td><td>&nbsp;</td>';
+
+            }
+          else
+            {
+           
+          $j++;
+	  print "\n".'<tr class="'. utils_get_alt_row_color($j).'">';
 
 	  # Date
-	  print '<td align="center">'.format_date($sys_datefmt,db_result($result, $i, 'date')).'</td>';  
+	  print '<td align="center" class="smaller">'.format_date($sys_datefmt,$date).'</td>';  
+          
 	  # Person
-	  print '<td align="center">'.utils_user_link(db_result($result, $i, 'user_name')).'</td>';
-	  # Updated Field
-	  print '<td>'.$field.'</td>';
+	  print '<td align="center" class="smaller">'.utils_user_link($user).'</td>';
+            }
 
-	  # Previous value
-	  print '<td>';
+          $previous_date = $date;
+          $previous_user = $user;
+
+	  # Updated Field
+	  print '<td class="smaller" align="center">'.$field_label.'</td>';
+
+	  # Previous value 
+	  print '<td class="smaller" align="right">';
 	  if (trackers_data_is_select_box($field))
 	    {
-	      # It's a select box look for value in clear
-	      print trackers_data_get_value($field, $group_id, $value_id);
+	      # Its a select box look for value in clear
+              if ($value_id == "transition-other-field-update")
+                {
+	          print "-"._("Automatic update due to transitions settings")."-"; 
+                }
+              else
+                {
+                  print trackers_data_get_value($field, $group_id, $value_id);
+                }
 	    }
 	  else if (trackers_data_is_date_field($field))
 	    {
@@ -277,10 +324,9 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
 	      # It's a text zone then display directly
 	      print $value_id;
 	    }
-	  print '</td>';
-
+        
+           print '</td><td class="smaller" align="center"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="=>" /></td><td class="smaller" align="left">';
 	  # New value
-	  print '<td>';
 	  if (trackers_data_is_select_box($field))
 	    {
 	      # It's a select box look for value in clear
@@ -357,8 +403,8 @@ function show_dependent_item ($item_id, $dependson=0)
   if (!$dependson) 
     { print _("Item(s) that depend on this one:"); }
   else 
-    { print _("Depends on the following item(s):").'</font>'; }
-  print '</font>';
+    { print _("Depends on the following item(s):"); }
+  print '</font> ';
 
   # Slurps the database.
   while (list($num, $art) = each($artifacts)) 
@@ -456,6 +502,20 @@ function show_dependent_item ($item_id, $dependson=0)
 	    }
 	} 
       print '</table>';
+      
+     # Link to digest dependant items
+      if ($dependson) 
+	{ 
+	  reset($artifacts);
+	  while (list(,$art) = each($artifacts)) 
+	    {
+	      if ($rows[$art] > 0)
+		{
+		  print utils_link($GLOBALS['sys_home'].$art.'/?group_id='.$group_id.'&amp;func=digestselectfield&amp;dependencies_of_item='.$item_id.'&amp;dependencies_of_tracker='.ARTIFACT, '['.sprintf(_("Digest %s depends"), $art).']').' '; 
+		}
+	    }
+	}
+
     }
   else
     {
