@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: editqueryforms.php,v 1.8 2004/09/22 08:11:51 yeupou Exp $
+# $Id: editqueryforms.php,v 1.10 2004/11/24 16:03:19 yeupou Exp $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
@@ -44,6 +44,9 @@ trackers_init($group_id);
 if ($post_changes)
 {
 
+  # scope is always project scope
+  $rep_scope = "P";
+
   if ($update_report)
     {
       # Updat report name and description and delete old report entries
@@ -199,10 +202,23 @@ if ($new_report)
       print "\n<td>".trackers_data_get_label($field).'</td>'.
 	"\n<td>".trackers_data_get_description($field).'</td>'.
 	"\n<td align=\"center\">".'<input type="checkbox" name="'.$cb_search.'" value="1"></td>'.
-	"\n<td align=\"center\">".'<input type="text" name="'.$tf_search.'" value="" size="5" maxlen="5"></td>'.
-	"\n<td align=\"center\">".'<input type="checkbox" name="'.$cb_report.'" value="1"></td>'.
-	"\n<td align=\"center\">".'<input type="text" name="'.$tf_report.'" value="" size="5" maxlen="5"></td>'.
-	"\n<td align=\"center\">".'<input type="text" name="'.$tf_colwidth.'" value="" size="5" maxlen="5"></td>'.
+	"\n<td align=\"center\">".'<input type="text" name="'.$tf_search.'" value="" size="5" maxlen="5"></td>';
+      
+     # If the current field is item id, we force it's presence on the report
+     # with rank 0. This field is mandatory: otherwise some links would be
+     # broken or there would be even no links.
+  if ($field == 'bug_id') 
+   {
+     print "\n<td align=\"center\"><input type=\"hidden\" name=\"".$cb_report."\" value=\"1\" />X</td>".
+       "\n<td align=\"center\"><input type=\"hidden\" name=\"".$tf_report."\" value=\"0\" />0</td>";
+   }
+ else
+   {
+     print "\n<td align=\"center\">".'<input type="checkbox" name="'.$cb_report.'" value="1" '.$cb_report_chk.' ></td>'.
+       "\n<td align=\"center\">".'<input type="text" name="'.$tf_report.'" value="'.$tf_report_val.'" size="5" maxlen="5"></td>';
+   }
+
+    print "\n<td align=\"center\">".'<input type="text" name="'.$tf_colwidth.'" value="" size="5" maxlen="5"></td>'.
 	'</tr>';
       $i++;
     }
@@ -257,22 +273,24 @@ if ($new_report)
 	   <input type="hidden" name="group_id" value="'.$group_id.'">
 	   <input type="hidden" name="report_id" value="'.$report_id.'">
 	   <input type="hidden" name="post_changes" value="y">
-	   <b>'._("Name:").' </b>
-	   <input type="text" name="rep_name" value="'.db_result($res,0,'name').'" size="20" maxlength="20">
-                 &nbsp;&nbsp;&nbsp;&nbsp;<b>'._("Scope:").' </b>';
-  $scope = db_result($res,0,'scope');
-  if (user_ismember($group_id,'A'))
-    print '<SELECT NAME="rep_scope">
-                        <option value="i"'.($scope=='i' ? 'selected':'').'>'._("Personal").'</option>
-                        <option value="p"'.($scope=='p' ? 'selected':'').'>'._("Project").'</option>
-                        </select>';
-  else
-    print ($scope=='P' ? 'Project':'Personal').
-      '<input type="hidden" name="rep_scope" value="'.$scope.'">';
+	   <font class="preinput">'._("Name:").' </font><br />&nbsp;&nbsp;&nbsp;
+	   <input type="text" name="rep_name" value="'.db_result($res,0,'name').'" size="20" maxlength="20">';
+
+
+ #                &nbsp;&nbsp;&nbsp;&nbsp;<b>'._("Scope:").' </b>';
+  #$scope = db_result($res,0,'scope');
+  #if (user_ismember($group_id,'A'))
+  #  print '<SELECT NAME="rep_scope">
+  #                      <option value="i"'.($scope=='i' ? 'selected':'').'>'._("Personal").'</option>
+  #                      <option value="p"'.($scope=='p' ? 'selected':'').'>'._("Project").'</option>
+  #                      </select>';
+  #else
+  #  print ($scope=='P' ? 'Project':'Personal').
+  #    '<input type="hidden" name="rep_scope" value="'.$scope.'">';
 
   print '
 	    <p>
-	    <b>'._("Description:").'</b>
+	       <font class="preinput">'._("Description:").'</font><br />&nbsp;&nbsp;&nbsp;
 	    <input type="text" name="rep_desc" value="'.db_result($res,0,'description').'" size="50" maxlength="120"></p>
                   <p>';
 
@@ -299,26 +317,37 @@ if ($new_report)
       $tf_report = 'TFREP_'.$field;
       $tf_colwidth = 'TFCW_'.$field;
 
-      $cb_search_chk = ($fld[$field]['show_on_query'] ? 'CHECKED':'');
-      $cb_report_chk = ($fld[$field]['show_on_result'] ? 'CHECKED':'');
+      $cb_search_chk = ($fld[$field]['show_on_query'] ? 'checked="checked"':'');
+      $cb_report_chk = ($fld[$field]['show_on_result'] ? 'checked="checked"':'');
       $tf_search_val = $fld[$field]['place_query'];
       $tf_report_val = $fld[$field]['place_result'];
       $tf_colwidth_val = $fld[$field]['col_width'];
 
-      print '<TR class="'. utils_get_alt_row_color($i) .'">';
+      print '<tr class="'. utils_get_alt_row_color($i) .'">';
 
       print "\n<td>".trackers_data_get_label($field).'</td>'.
 	"\n<td>".trackers_data_get_description($field).'</td>'.
 	"\n<td align=\"center\">".'<input type="checkbox" name="'.$cb_search.'" value="1" '.$cb_search_chk.' ></td>'.
-	"\n<td align=\"center\">".'<input type="text" name="'.$tf_search.'" value="'.$tf_search_val.'" size="5" maxlen="5"></td>'.
-	"\n<td align=\"center\">".'<input type="checkbox" name="'.$cb_report.'" value="1" '.$cb_report_chk.' ></td>'.
-	"\n<td align=\"center\">".'<input type="text" name="'.$tf_report.'" value="'.$tf_report_val.'" size="5" maxlen="5"></td>'.
-	"\n<td align=\"center\">".'<input type="text" name="'.$tf_colwidth.'" value="'.$tf_colwidth_val.'" size="5" maxlen="5"></td>'.
-	'</tr>';
+	"\n<td align=\"center\">".'<input type="text" name="'.$tf_search.'" value="'.$tf_search_val.'" size="5" maxlen="5"></td>';
+     # If the current field is item id, we force it's presence on the report
+# with rank 0. This field is mandatory: otherwise some links would be
+     # broken or there would be even no links.
+ if ($field == 'bug_id') 
+   {
+     print "\n<td align=\"center\"><input type=\"hidden\" name=\"".$cb_report."\" value=\"1\" />X</td>".
+       "\n<td align=\"center\"><input type=\"hidden\" name=\"".$tf_report."\" value=\"0\" />0</td>";
+   }
+ else
+   {
+     print "\n<td align=\"center\">".'<input type="checkbox" name="'.$cb_report.'" value="1" '.$cb_report_chk.' ></td>'.
+       "\n<td align=\"center\">".'<input type="text" name="'.$tf_report.'" value="'.$tf_report_val.'" size="5" maxlen="5"></td>';
+   }
+     print "\n<td align=\"center\">".'<input type="text" name="'.$tf_colwidth.'" value="'.$tf_colwidth_val.'" size="5" maxlen="5"></td>'.
+       '</tr>';
       $i++;
     }
   print '</table>'.
-    '<p><center><input type="submit" name="submit" value="Submit"></center>'.
+    '<p><center><input type="submit" name="submit" value="'._("Submit").'"></center>'.
     '</form>';
 
 }
