@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_values.php,v 1.19 2004/09/22 16:05:59 yeupou Exp $
+# $Id: field_values.php,v 1.21 2004/11/22 08:25:50 yeupou Exp $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
@@ -26,9 +26,7 @@
 
 $is_admin_page='y';
 
-if ($group_id && 
-    (user_ismember($group_id,'B2') || 
-     user_ismember($group_id,'A')))
+if ($group_id && user_ismember($group_id,'A'))
 {
 # Initialize global bug structures
   trackers_init($group_id);
@@ -38,7 +36,7 @@ if ($group_id &&
   
   if ($func == "deltransition")
     {
-      $sql="DELETE FROM trackers_field_transition WHERE transition_id = '".$transition_id."' LIMIT 1";
+      $sql="DELETE FROM trackers_field_transition WHERE transition_id = '".addslashes($transition_id)."' LIMIT 1";
       $result=db_query($sql);
       if (!$result)
 	{
@@ -49,11 +47,14 @@ if ($group_id &&
 	  fb(_("Transition deleted"));
 	}
     }
-  elseif ($post_changes)
+  elseif ($post_changes || $delete_canned)
     {
     # A form of some sort was posted to update or create
     # an existing value
-
+	
+	# Deleted Canned doesn't need a forum, so let switch
+	# into this code
+	
       if ($create_value)
 	{
           # A form was posted to update a field value
@@ -90,9 +91,9 @@ if ($group_id &&
 	{
 
           # A form was posted to create a canned response
-	  $sql="INSERT INTO ".ARTIFACT."_canned_responses (group_id,title,body) ".
+	  $sql="INSERT INTO ".ARTIFACT."_canned_responses (group_id,title,body,order_id) ".
 	     " VALUES ('$group_id','". htmlspecialchars($title) .
-	     "','". htmlspecialchars($body) ."')";
+	     "','". htmlspecialchars($body) ."','".addslashes($order_id)."')";
 	  $result=db_query($sql);
 	  if (!$result)
 	    {
@@ -106,11 +107,10 @@ if ($group_id &&
 	}
       else if ($update_canned)
 	{
-
           # A form was posted to update a canned response
 	  $sql="UPDATE ".ARTIFACT."_canned_responses ".
-	     "SET title='". htmlspecialchars($title) ."', body='". htmlspecialchars($body).
-	     "' WHERE group_id='$group_id' AND bug_canned_id='$item_canned_id'";
+	     "SET title='". htmlspecialchars($title) ."', body='". htmlspecialchars($body)."', order_id='".addslashes($order_id)."'".
+	     " WHERE group_id='$group_id' AND bug_canned_id='$item_canned_id'";
 	  $result=db_query($sql);
 	  if (!$result)
 	    {
@@ -121,16 +121,28 @@ if ($group_id &&
 	      fb(_("Canned bug response updated"));
 	    }
 	}
-
+		# Delete Response
+		else if ($_GET['delete_canned'] == '1')
+	{
+		$sql="DELETE FROM ".ARTIFACT."_canned_responses ".
+		"WHERE group_id='".addslashes($group_id)."' AND bug_canned_id='".addslashes($item_canned_id)."'";
+		$result=db_query($sql);
+		if (!$result) {
+			fb(_("Error deleting canned bug response"),1);
+		}
+		else
+		{
+			fb(_("Canned bug response deleted"));
+		}
     }
-
+}
   
   $field_id = ($by_field_id ? $field : trackers_data_get_field_id($field));
 
    
   if ($to != $from) {
     # A form was posted to update or create a transition
-    $sql="SELECT from_value_id,to_value_id,is_allowed,assign_to,notification_list ".
+    $sql="SELECT from_value_id,to_value_id,is_allowed,notification_list ".
        "FROM trackers_field_transition ".
        "WHERE group_id='$group_id' AND artifact='".ARTIFACT."' AND field_id='$field_id' AND from_value_id='$from' AND to_value_id='$to' ";
     $res_value = db_query($sql);
@@ -141,8 +153,8 @@ if ($group_id &&
       {
 	
 	$sql = "INSERT INTO  trackers_field_transition ".
-	   "(group_id,artifact,field_id,from_value_id,to_value_id,is_allowed,assign_to,notification_list) ".
-	   "VALUES ('$group_id','".ARTIFACT."','$field_id','$from','$to','$allowed','$assign_to','$mail_list')";
+	   "(group_id,artifact,field_id,from_value_id,to_value_id,is_allowed,notification_list) ".
+	   "VALUES ('$group_id','".ARTIFACT."','$field_id','$from','$to','$allowed','$mail_list')";
 	$result = db_query($sql);
  
 	if (db_affected_rows($result) < 1)
@@ -154,7 +166,7 @@ if ($group_id &&
       {
         # update the existing entry for this transition
 	$sql = "UPDATE trackers_field_transition ".
-	   "SET is_allowed='$allowed',assign_to='$assign_to',notification_list='$mail_list' ".
+	   "SET is_allowed='$allowed',notification_list='$mail_list' ".
 	   "WHERE group_id='$group_id' AND artifact='".ARTIFACT."' AND field_id='$field_id'  AND from_value_id='$from' AND to_value_id='$to' ";
 	$result = db_query($sql);
 
@@ -199,7 +211,7 @@ if ($group_id &&
 
 	  if ($result && $rows > 0)
 	    {
-	      print "\n<h3>"._("Existing Values").'</h3>';
+	      print "\n<h3>".html_anchor(_("Existing Values"),"existing").'</h3>';
 
 	      $title_arr=array();
 	      if (!$is_project_scope)
@@ -208,6 +220,7 @@ if ($group_id &&
 	      $title_arr[]=_("Description");
 	      $title_arr[]=_("Rank");
 	      $title_arr[]=_("Status");
+	      $title_arr[]=_("Occurences");
 
 
 	      $hdr = html_build_list_table_top ($title_arr);
@@ -226,6 +239,7 @@ if ($group_id &&
 		  $value = $fld_val['value'];
 		  $description = $fld_val['description'];
 		  $order_id = $fld_val['order_id'];
+                  $usage = trackers_data_count_field_value_usage($group_id, $field, $value_id);
 
 		  $html = '';
 
@@ -247,12 +261,21 @@ if ($group_id &&
 		    {
 		      $html .= '<td><a href="'.$PHP_SELF.'?update_value=1'.
 			 '&fv_id='.$item_fv_id.'&field='.$field.
-			 '&group_id='.$group_id.'">'.$value.'</A></td>';
+		      '&group_id='.$group_id.'">'.$value.'</A></td>';
 		    }
+		    
+		   $html .= '<td>'.$description.'&nbsp;</td>'.
+                        '<td align="center">'.$order_id.'</td>'.
+                        '<td align="center">'.$status_stg[$status].'</td>';
 
-		  $html .= '<td>'.$description.'&nbsp;</td>'.
-		     '<td align="center">'.$order_id.'</td>'.
-		     '<td align="center">'.$status_stg[$status].'</td>';
+		  if ($status == 'H' && $usage > 0)
+                   {
+                     $html .= '<td align="center"><b class="warn">'.$usage.'</b></td>';
+                   }
+		  else
+      {
+	 $html .= '<td align="center">'.$usage.'</td>';
+      }
 
 		  if ($status == 'A' || $status == 'P')
 		    {
@@ -300,7 +323,7 @@ if ($group_id &&
 	    {
 
 	      print '<br />';
-	      print '<h3>'._("Create a new field value").'</h3>';
+	      print '<h3>'.html_anchor(_("Create a new field value"),"create").'</h3>';
 
 	      if ($ih)
 		{
@@ -330,7 +353,7 @@ if ($group_id &&
 
 	      print '
       <p>
-      <span class="preinput">'._("Description:").'</span> ('._("optional").')<br />
+      <span class="preinput">'._("Description (optional):").'</span><br />
       <textarea name="description" rows="4" cols="65" wrap="hard"></textarea></p>
       <p class="center">
       <input type="submit" name="submit" value="'._("Update").'" /></p>
@@ -357,7 +380,7 @@ if ($group_id &&
           # First get all the value_id - value pairs
            $sql="SELECT value_id,value ".
                "FROM ".ARTIFACT."_field_value ".
-               "WHERE group_id=$group_id AND bug_field_id=$field_id";
+               "WHERE group_id='".addslashes($group_id)."' AND bug_field_id='".addslashes($field_id)."'";
           $res_value = db_query($sql);
           $rows=db_numrows($res_value);
 
@@ -375,7 +398,7 @@ if ($group_id &&
             {
             $sql="SELECT value_id,value ".
                  "FROM ".ARTIFACT."_field_value ".
-                 "WHERE group_id=100 AND bug_field_id=$field_id";
+                 "WHERE group_id=100 AND bug_field_id='".addslashes($field_id)."'";
             $res_value = db_query($sql);
             $rows=db_numrows($res_value);
 
@@ -391,22 +414,22 @@ if ($group_id &&
              }
           }
 
-          $sql="SELECT transition_id,from_value_id,to_value_id,is_allowed,assign_to,notification_list ".
+          $sql="SELECT transition_id,from_value_id,to_value_id,is_allowed,notification_list ".
           "FROM trackers_field_transition ".
-          "WHERE group_id='$group_id' AND artifact='".ARTIFACT."' AND field_id='$field_id' ";
+          "WHERE group_id='".addslashes($group_id)."' AND artifact='".ARTIFACT."' AND field_id='".addslashes($field_id)."' ";
 
           $result = db_query($sql);
           $rows = db_numrows($result);
 
           if ($result && $rows > 0)
             {
-              print "\n<h3>"._("Registered Transitions").'</h3>';
+              print "\n\n<p>&nbsp;</p><h3>".html_anchor(_("Registered Transitions"),"registered").'</h3>';
 
               $title_arr=array();
               $title_arr[]=_("From");
               $title_arr[]=_("To");
               $title_arr[]=_("Is Allowed");
-              $title_arr[]=_("Assign To");
+              $title_arr[]=_("Others Fields Update");
               $title_arr[]=_("Carbon-Copy List");
               $title_arr[]=_("Delete?");
 
@@ -415,40 +438,61 @@ if ($group_id &&
               print $hdr;
 
               $reg_default_auth = '';
+	      $z = 1;
               while ($transition = db_fetch_array($result))
                 {
-
+		  $z++;
                   if ($transition['is_allowed'] == 'A') {
                     $allowed = _("Yes");
                   } else {
                     $allowed = _("No");
                   }
-                  $assign_to = trackers_field_display('assigned_to',$group_id,$transition['assign_to'],false,false,true,true,true,'not reassigned');
 
-                 print '<tr class="center">';
+                 print '<tr class="'.utils_altrow($z).'">';
                  if ($val_label[$transition['from_value_id']])
                    {
-                     print '<td>'.$val_label[$transition['from_value_id']].'</td>';
+                     print '<td align="center">'.$val_label[$transition['from_value_id']].'</td>';
                    }
                  else
                    {
-                     print '<td>'._("* - Any").'</td>'; 
+                     print '<td  align="center">'._("* - Any").'</td>'; 
                    }
 
-                 print '<td>'.$val_label[$transition['to_value_id']].'</td>'
-                       .'<td>'.$allowed.'</td>';
+                 print '<td align="center">'.$val_label[$transition['to_value_id']].'</td>'
+                       .'<td align="center">'.$allowed.'</td>';
 
                   if ($transition['is_allowed'] == 'A') 
                      {
-                      print '<td>'.$assign_to.'</td>'
-                       .'<td>'.$transition['notification_list'].'</td>';
+		       print '<td align="center">';
+		       # Get list of registered field updates
+		       $registered = trackers_transition_get_other_field_update($transition['transition_id']);
+		       # Make sure $content is clean
+		       unset($content);
+		       # No result? Print only a link
+		       if ($registered)
+			 {
+			   while ($entry = db_fetch_array($registered))
+			     {
+			       # Add one entry per registered other field update
+			       $content .= trackers_data_get_label($entry['update_field_name']).":".trackers_data_get_value($entry['update_field_name'], $group_id, $entry['update_value_id']).", ";
+			     }
+			   # Remove extra comma
+			   $content = trim($content, ", ");
+			 }
+		       else
+			 {
+			   $content = _("Edit others fields update");
+			 }
+
+		       print utils_link($GLOBALS['sys_home'].ARTIFACT."/admin/field_values_transition-ofields-update.php?group=".$group_name."&amp;transition_id=".$transition['transition_id'], $content);
+		       print '</td><td align="center">'.$transition['notification_list'].'</td>';
                      }
                     else
                      {
-                       print '<td>---------</td>'
-                       .'<td>--------</td>';
+                       print '<td align="center">---------</td>'
+                       .'<td align="center">--------</td>';
                      }
-                  print '<td>'.utils_link($PHP_SELF.'?group='.$group_name.'&amp;func=deltransition&amp;transition_id='.$transition['transition_id'].'&amp;list_value=1&amp;field='.$field, '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Delete this transition?").'" />').'</td>';
+                  print '<td align="center">'.utils_link($PHP_SELF.'?group='.$group_name.'&amp;func=deltransition&amp;transition_id='.$transition['transition_id'].'&amp;list_value=1&amp;field='.$field, '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Delete this transition?").'" />').'</td>';
                   print '</tr>';
                 }
                
@@ -457,12 +501,12 @@ if ($group_id &&
           else
             {
               $reg_default_auth = '';
-              printf ("\n<h3>"._("No transition defined yet for %s").'</h3>',trackers_data_get_label($field));
+              printf ("\n\n<p>&nbsp;</p><h3>"._("No transition defined yet for %s").'</h3>',trackers_data_get_label($field));
             }
 
       
               print '
-                     <form action="'.$PHP_SELF.'" method="post">
+                     <form action="'.$PHP_SELF.'#registered" method="post">
                      <input type="hidden" name="post_transition_changes" value="y" />
                      <input type="hidden" name="list_value" value="y" />
                      <input type="hidden" name="tracker_name" value="'.ARTIFACT.'" />
@@ -477,15 +521,15 @@ if ($group_id &&
                  {
                    $auth = _("Allowed");
                  }
-              print '<h3>'._("Create / Edit a transition").'</h3>';
+              print "\n\n<p>&nbsp;</p><h3>".html_anchor(_("Create / Edit a transition"),"create").'</h3>';
 
               print '<p>'.sprintf(_("By default, for this field, the transitions not registered are %s. This setting can be changed when managing this field usage."),$auth).'</p>';
+              print '<p>'._("Once a transition created, it will be possible to set \"Others Fields Update\" for this transition.").'</p>';
 
               $title_arr=array();
               $title_arr[]=_("From");
               $title_arr[]=_("To");
               $title_arr[]=_("Is Allowed");
-              $title_arr[]=_("Assign To");
               $title_arr[]=_("Carbon-Copy List");
 
               $auth_label = array();
@@ -503,13 +547,11 @@ if ($group_id &&
 
               print '<td>'.html_build_select_box_from_arrays ($auth_val,$auth_label,'allowed', 'allowed',false).'</td>';
 
-              $rea = '<td>'.trackers_field_box('assigned_to','assign_to',$group_id,false,true,'not reassigned').'</td>';
-
               $mlist   = '<td>'.'
               <input type="text" name="mail_list" value="" size="30" maxlength="60" />
               </td>';
 
-              print $rea.$mlist.'</tr></table>';
+              print $mlist.'</tr></table>';
 
               print '<p align="center"><input type="submit" name="submit" value="'._("Update Transition").'" /></p>
                      </form>';
@@ -517,7 +559,7 @@ if ($group_id &&
       else
         {
 
-          print '<h3>';
+          print "\n\n<p>&nbsp;</p><h3>";
           printf (_("The Bug field you requested '%s' is not used by your project or you are not allowed to customize it"),$field);
           print '</h3>';
         }
@@ -553,26 +595,32 @@ if ($group_id &&
       <select name="status">
 	   <option value="A">'
 	._("Active").'</option>
-	   <option value="H"'.((db_result($res,0,'status') == 'h') ? ' selected':'').'>'
+	   <option value="H"'.((db_result($res,0,'status') == 'H') ? ' selected="selected"':'').'>'
 	._("Hidden").'</option>
       </select>
       <p>
-      <span class="preinput">'._("Description:").' </span> ('
-	._("optional").')<br />
-      <textarea name="description" rows="4" cols="65" wrap="soft">'.db_result($res,0,'description').'</textarea></p>
-      <p>
+      <span class="preinput">'._("Description: (optional)").'<br />
+      <textarea name="description" rows="4" cols="65" wrap="soft">'.db_result($res,0,'description').'</textarea></p>';
+
+      $count = trackers_data_count_field_value_usage($group_id, $field, db_result($res,0,'value_id'));
+      if ($count > 0) 
+       {
+         print '<p class="warn">'.sprintf(_("This field value applies to %s items of your tracker. If you hide this field value, the related items will have no value in the field '%s'."),$count,$field).'</p>';
+       } 
+     print '
+      <p class="center">
       <input type="submit" name="submit" value="'._("Submit").'" /></p>';
 
 
     }
-  else if ($create_canned)
+  else if ($create_canned || $delete_canned)
     {
       /*
 	  Show existing responses and UI form
       */
       trackers_header_admin(array ('title'=>_("Create/Modify Canned Responses")));
 
-      $sql="SELECT bug_canned_id,title,body FROM ".ARTIFACT."_canned_responses WHERE group_id='$group_id'";
+      $sql="SELECT * FROM ".ARTIFACT."_canned_responses WHERE group_id='$group_id' ORDER BY order_id ASC";
       $result=db_query($sql);
       $rows=db_numrows($result);
 
@@ -581,35 +629,41 @@ if ($group_id &&
 	  /*
 	      Links to update pages
 	  */
-	  print "\n<h2>"._("Existing Responses:").'</h2><p>';
+	  print "\n<h3>"._("Existing Responses:").'</h3><p>';
 
 	  $title_arr=array();
 	  $title_arr[]=_("Title");
-	  $title_arr[]=_("Body (extract)");
+	  $title_arr[]=_("Body (abstract)");
+	  $title_arr[]=_("Rank");
+	  $title_arr[]=_("Delete");
 
 	  print html_build_list_table_top ($title_arr);
 
 	  for ($i=0; $i < $rows; $i++)
 	    {
+             # FIXME: delete should use the basket, like it is done in many
+             # other places
 	      print '<tr class="'. utils_get_alt_row_color($i) .'">'.
 		'<td><a href="'.$PHP_SELF.'?update_canned=1&amp;item_canned_id='.
 		db_result($result, $i, 'bug_canned_id').'&amp;group_id='.$group_id.'">'.
 		db_result($result, $i, 'title').'</A></TD>'.
-		'<td>'.substr(db_result($result, $i, 'body'),0,160).
-		'<b>...</b></td></tr>';
+		'<td>'.substr(db_result($result, $i, 'body'),0,360).'...'.
+		'<td>'.db_result($result, $i, 'order_id').'<td><a href="'.$PHP_SELF.'?delete_canned=1&amp;item_canned_id='.
+		db_result($result, $i, 'bug_canned_id').'&amp;group_id='.$group_id.'">
+		Delete</a></td></tr>';
 	    }
 	  print '</table>';
 
 	}
       else
 	{
-	  print "\n<h2>"._("No canned bug responses set up yet").'</h2>';
+	  print "\n<h3>"._("No canned bug responses set up yet").'</h3>';
 	}
       /*
 	  Escape to print the add response form
       */
 
-      print '<h2>'._("Create a new response").'</h2>
+      print '<h3>'._("Create a new response").'</h3>
      <p>
      '._("Creating generic quick responses can save a lot of time when giving common responses.").'</p>
      <p>
@@ -617,12 +671,15 @@ if ($group_id &&
      <input type="hidden" name="create_canned" value="y">
      <input type="hidden" name="group_id" value="'.$group_id.'">
      <input type="hidden" name="post_changes" value="y">
-     <b>'._("Title:").'</b><br />
-     <input type="text" name="title" value="" size="50" maxlength="50"></p>
+     <span class="preinput">'._("Title:").'</span><br />
+     &nbsp;&nbsp;<input type="text" name="title" value="" size="50" maxlength="50"></p>
      <p>
-     <b>'._("Message Body:").'</b><br />
-     <textarea name="body" rows="20" cols="65" wrap="hard"></textarea></p>
+     <span class="preinput">'._("Rank (useful in multiple canned responses):").'</span><br />
+     &nbsp;&nbsp;<input type="text" name="order_id" value="" maxlength="50"></p>
      <p>
+     <span class="preinput">'._("Message Body:").'</span><br />
+     &nbsp;&nbsp;<textarea name="body" rows="20" cols="65" wrap="hard"></textarea></p>
+     <p class="center">
      <input type="submit" name="submit" value="'._("Submit").'"></p>
      </form>';
 
@@ -631,21 +688,17 @@ if ($group_id &&
     }
   else if ($update_canned)
     {
-      /*
-	  Allow change of canned responses
-      */
+      #  Allow change of canned responses
       trackers_header_admin(array ('title'=>_("Modify Canned Response")));
 
-      #	print '<h2>'._("Modify Canned Response").'</h2>';
-
-      $sql="SELECT bug_canned_id,title,body FROM ".ARTIFACT."_canned_responses WHERE ".
-	 "group_id='$group_id' AND bug_canned_id='$item_canned_id'";
+      $sql="SELECT bug_canned_id,title,body,order_id FROM ".ARTIFACT."_canned_responses WHERE ".
+	 "group_id='".addslashes($group_id)."' AND bug_canned_id='".addslashes($item_canned_id)."'";
 
       $result=db_query($sql);
 
       if (!$result || db_numrows($result) < 1)
 	{
-	  print "\n<h2>"._("No such response!").'</h2>';
+           fb(_("No such response!"),1);
 	}
       else
 	{
@@ -661,12 +714,15 @@ if ($group_id &&
       <input type="hidden" name="group_id" value="'.$group_id.'">
       <input type="hidden" name="item_canned_id" value="'.$item_canned_id.'">
       <input type="hidden" name="post_changes" value="y">
-      <b>'._("Title").':</b><br />
-      <input type="text" name="title" value="'.db_result($result,0,'title').'" size="50" maxlength="50"></p>
+      <span class="preinput">'._("Title").':</span><br />
+      &nbsp;&nbsp;<input type="text" name="title" value="'.db_result($result,0,'title').'" size="50" maxlength="50"></p>
       <p>
-      <b>'._("Message Body:").'</b><br />
-      <textarea name="body" rows="20" cols="65" wrap="hard">'.db_result($result,0,'body').'</textarea></p>
+      <span class="preinput">'._("Rank").':</span><br />
+      &nbsp;&nbsp;<input type="text" name="order_id" value="'.db_result($result,0,'order_id').'"></p>
       <p>
+      <span class="preinput">'._("Message Body:").'</span><br />
+      &nbsp;&nbsp;<textarea name="body" rows="20" cols="65" wrap="hard">'.db_result($result,0,'body').'</textarea></p>
+      <p class="center">
       <input type="submit" name="submit" value="Submit"></p>
       </form>';
 
@@ -676,10 +732,9 @@ if ($group_id &&
   else
     {
 
-      trackers_header_admin(array ('title'=>_("Field Values Management")));
+     ######## Complete list of fields
 
-      print '<h2>'._("List of all Available Fields").'</h2>';
-      print '<p>('._("Click to modify").')</p>';
+      trackers_header_admin(array ('title'=>_("Field Values Management")));
 
       # Loop through the list of all used fields that are project manageable
       $i=0;
