@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: browse.php,v 1.30 2004/09/22 08:11:51 yeupou Exp $
+# $Id: browse.php,v 1.32 2004/11/25 14:44:27 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -24,8 +24,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-
-
 # Number of search criteria (boxes) displayed in one row
 $fields_per_line=5;
 
@@ -34,6 +32,16 @@ $fields_per_line=5;
 if (!$chunksz)
 { $chunksz = 50; }
 
+# Digest mode? Set the digest variable to one
+if ($func == "digest")
+{ $digest = 1; }
+else
+{ 
+  $digest = 0; 
+  $func = "browse";
+} 
+
+
 # Make sure offset is defined and has a correct value
 if (!$offset || $offset < 0)
 { $offset=0; }
@@ -80,7 +88,7 @@ while (list($field,$value_id) = each($prefs))
 	  $field_op = $field.'_op';
 	  $prefs[$field_op] = $$field_op;
 	  if (!$prefs[$field_op])
-	    $prefs[$field_op] = '>';
+	    { $prefs[$field_op] = '='; }
 	  #print '<br /> DBG Setting $prefs['.$field.'_op]= '.$prefs[$field.'_op'];
 	}
     }
@@ -132,7 +140,7 @@ if (isset($morder))
     }
 }
 
-#print "<BR> DBG Order by = $order_by";
+#print "<BR>>DBG Order by = $order_by";
 
 
 /* ==================================================
@@ -294,9 +302,6 @@ $select_count = 'SELECT count(*) AS count ';
 $select = 'SELECT '.ARTIFACT.'.priority,'.ARTIFACT.'.privacy,'.ARTIFACT.'.status_id';
 $from = 'FROM '.ARTIFACT.' ';
 $where = 'WHERE '.ARTIFACT.'.group_id='.$group_id.' ';
-if (!$pv)
-{ $limit = " LIMIT $offset,$chunksz";}
-
 
 # prepare the where clause with the selection criteria given by the user
 reset($prefs);
@@ -321,12 +326,15 @@ while (list($field,$value_id) = each($prefs))
       
 # transform a date field into a unix time and use <, > or =
       list($time,$ok) = utils_date_to_unixtime($prefs[$field][0]);
-      
+      preg_match("/\s*(\d+)-(\d+)-(\d+)/", $prefs[$field][0],$match);
+      list(,$year,$month,$day) = $match;
+
       if ($advsrch)
 	{
 	  list($time_end,$ok_end) = utils_date_to_unixtime($prefs[$field.'_end'][0]);
 	  if ($ok)
-	    { $where .= ' AND '.ARTIFACT.'.'.$field.' >= '. $time; }
+	    { 
+	      $where .= ' AND '.ARTIFACT.'.'.$field.' >= '. $time; }
 	  
 	  if ($ok_end)
 	    { $where .= ' AND '.ARTIFACT.'.'.$field.' <= '. $time_end; }
@@ -344,6 +352,7 @@ while (list($field,$value_id) = each($prefs))
 	    }
 	  else
 	    {
+	      $time = mktime(0,0,0, $month, ($day+1), $year);
 	      $where .= ' AND '.ARTIFACT.'.'.$field." $operator= $time ";
 	    }
 	}
@@ -378,7 +387,7 @@ while ($field = trackers_list_all_fields(cmp_place_query))
   # beginning of a new row
   if ($ib % $fields_per_line == 0)
     {
-      $align = ($pv ? "left" : "center");
+      $align = ($printer ? "left" : "center");
       $labels .= "\n".'<tr align="'.$align.'" valign="top">';
       $boxes .= "\n".'<tr align="'.$align.'" valign="top">';
     }
@@ -397,7 +406,7 @@ while ($field = trackers_list_all_fields(cmp_place_query))
       $boxes .=
 	 trackers_field_display($field,$group_id,
 				($advsrch ? $prefs[$field] : $prefs[$field][0]),
-				false,false,($pv?true:false),false,true,'None', true,'Any');
+				false,false,($printer?true:false),false,true,'None', true,'Any');
       
     } 
   else if (trackers_data_is_date_field($field))
@@ -406,12 +415,12 @@ while ($field = trackers_list_all_fields(cmp_place_query))
       if ($advsrch)
 	{ 
 	  $boxes .= trackers_multiple_field_date($field,$prefs[$field][0],
-						 $prefs[$field.'_end'][0],0,0,$pv);
+						 $prefs[$field.'_end'][0],0,0,$printer);
 	}
       else
 	{
-	  $boxes .= trackers_field_date_operator($field,$prefs[$field.'_op'][0],$pv).
-	     trackers_field_date($field,$prefs[$field][0],0,0,$pv);
+	  $boxes .= trackers_field_date_operator($field,$prefs[$field.'_op'][0],$printer).
+	     trackers_field_date($field,$prefs[$field][0],0,0,$printer);
 	} 
       
     }
@@ -420,7 +429,7 @@ while ($field = trackers_list_all_fields(cmp_place_query))
 # yeupou--gnu.org 2004-09-17: how can we reach this elseif after an
 # if?	  
       $boxes .=
-	 ($pv ? $prefs[$field][0] : trackers_field_text($field,$prefs[$field][0],15,80)) ;
+	 ($printer ? $prefs[$field][0] : trackers_field_text($field,$prefs[$field][0],15,80)) ;
     }
 
   $boxes .= "</TD>\n";
@@ -447,6 +456,15 @@ if ($labels)
    Loop through the list of used fields to see what fields are in the
    result table and complement the SQL query accordingly.
   ================================================== */
+
+# Add extra digest column, if necessary
+if ($digest)
+{
+  $col_list[] = "digest";
+  $width_list[] = "";
+  $lbl_list[] = _("Digest");
+}
+
 while ( $field = trackers_list_all_fields(cmp_place_result))
 {
 
@@ -497,32 +515,32 @@ $result=db_query($sql);
    Display the HTML search form
   ================================================== */
 
-if ($pv)
+if ($printer)
 {
-  help_header(_("Item Search Report").' - '.format_date($sys_datefmt,time()),false);
+  trackers_header(array('title'=>_("Browse").' - '.format_date($sys_datefmt,time())));
 }
 else
 {
   trackers_header(array('title'=>_("Browse").' '.$hdr));
 }
 
+if ($browse_preamble)
+{ print $browse_preamble; }
+
 print '    <FORM ACTION="'.$PHP_SELF .'" METHOD="GET" NAME="bug_form">
-          <INPUT TYPE="HIDDEN" NAME="group_id" VALUE="'.$group_id.'">
+          <INPUT TYPE="HIDDEN" NAME="group" VALUE="'.$group_name.'">
+          <INPUT TYPE="HIDDEN" NAME="func" VALUE="'.$func.'">
           <INPUT TYPE="HIDDEN" NAME="set" VALUE="custom">
           <INPUT TYPE="HIDDEN" NAME="msort" VALUE="'.$msort.'">
           <h3>'._("Browse").' ';
 
 # Show the list of available bug reports kind
-if (!$pv)
-{
-  $res_report = trackers_data_get_reports($group_id,user_getid());
-  $box_name = 'report_id" onChange="document.bug_form.go_report.click()';
-
-  printf(_("with the %s query form"), html_build_select_box($res_report,$box_name,$report_id,true,'Basic'));
-}
+$res_report = trackers_data_get_reports($group_id,user_getid());
+$box_name = 'report_id" onChange="document.bug_form.go_report.click()';
+printf(_("with the %s query form"), html_build_select_box($res_report,$box_name,$report_id,true,'Basic'));
 
 # Start building the URL that we use to for hyperlink in the form
-$url = $GLOBALS['sys_home'].ARTIFACT."/?group=$group_name&amp;func=browse&amp;set=$set&amp;msort=$msort";
+$url = $GLOBALS['sys_home'].ARTIFACT."/?group=$group_name&amp;func=".$func."&amp;set=$set&amp;msort=$msort";
 if ($set == 'custom')
      $url .= $pref_stg;
      else
@@ -544,7 +562,7 @@ else
 }
 
 # Select 'list form' or 'select' form
-if (!$pv)
+if (!$printer)
 {
   if ($advsrch)
     {
@@ -555,10 +573,19 @@ if (!$pv)
       $advsrch_0 = ' selected="selected"';
     }
   printf(' '._("and %s selection."), '<select name="advsrch"><option value="0"'.$advsrch_0.'>'._("Simple").'</option><option value="1"'.$advsrch_1.'>'._("Multiple").'</option></select>');
+  print '<input value="'._("Apply").'" name="go_report" type="submit">';
+}
+else
+{
+  if ($advsrch)
+    { $advsrch_x = _("Multiple");  }
+  else
+    { $advsrch_x =  _("Simple");  }
+  
+  printf(' '._("and %s selection."), $advsrch_x);
 }
 
 # End the form type selection
-print '<input value="'._("Apply").'" name="go_report" type="submit">';
 print '</h3>';
 
 print '<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="5">
@@ -567,17 +594,31 @@ print '<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="5">
 print $html_select;
 
 print '</table>';
-if (!$pv)
+if (!$printer)
 {
   print '<p><font class="smaller">Show</font> '.
     '<input type="text" name="chunksz" size="3" maxlength="5" '.
     'value="'.$chunksz.'"> '._("items at once").'.</form>';
 }
+else
+{
+  print '<p><font class="smaller">Show</font> '.
+    $chunksz.' '._("items at once").'.</form>';
+}
 
 /* ==================================================
   Finally display the result table
  ================================================== */
 
+if ($digest)
+{
+  print '<form action="'.$PHP_SELF.'" method="get">
+<input type="hidden" name="group" value="'.$group_name.'" />
+<input type="hidden" name="func" value="digestselectfield" />
+';
+
+}
+
 $numrows = db_numrows($result);
 
 if ($result && $numrows > 0)
@@ -596,36 +637,33 @@ if ($result && $numrows > 0)
   # add the plural in brackets, so it looks a little nicer -- toddy 2004-02-29
   print '<h3>'.$totalrows.' '._("matching item(s)").' '.$order_statement.'</h3>';
 
-
-  if (!$pv)
+  
+  print '<p>';
+  if ($msort)
     {
-    print '<p>';
-    if ($msort)
-      {
-        $url_alternate_sort = str_replace('msort=1','msort=0',$url).'&amp;order=#results';
-        printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sdeactivate%s multicolumn sort."),
-          '<a href="'.$url.'&amp;order=priority#results"><b>', '</b></a>',
-          '<a href="'.$url.'&amp;order=#results"><b>', '</b></a>',
-          '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
+      $url_alternate_sort = str_replace('msort=1','msort=0',$url).'&amp;order=#results';
+      printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sdeactivate%s multicolumn sort."),
+	     '<a href="'.$url.'&amp;order=priority#results"><b>', '</b></a>',
+	     '<a href="'.$url.'&amp;order=#results"><b>', '</b></a>',
+	     '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
       }
-    else
+  else
       {
         $url_alternate_sort = str_replace('msort=0','msort=1',$url).'&order=#results';
         printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sactivate%s multicolumn sort."),
           '<a href="'.$url.'&amp;order=priority#results"><b>', '</b></a>',
           '<a href="'.$url.'&amp;order=#results"><b>', '</b></a>',
-          '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
+	       '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
       }
-      print '&nbsp;&nbsp;&nbsp;&nbsp;(<a href="'.$url.'&pv=1"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/print.png" border="0" />';
-      print '&nbsp;'._("Printer version").'</a>)</p>'."\n";
-    }
-  else
+  print '</p>'."\n";
+  show_item_list($result,$offset,$totalrows,$col_list,$lbl_list,$width_list,$url,false);
+  
+  if ($digest)
     {
-      $chunksz = 100000;
+      print form_footer(_("Proceed to Digest next step"));
     }
-  show_item_list($result,$offset,$totalrows,$col_list,$lbl_list,$width_list,
-	       ($pv ? '' : $url), ($pv ? true:false) );
-  show_priority_colors_key('Severity colors:');
+
+  show_priority_colors_key();
 
 }
 else
@@ -636,9 +674,6 @@ else
 
 }
 
-if ($pv)
-{ help_footer(); }
-else
-{ trackers_footer(array()); }
+trackers_footer(array());
 
 ?>
