@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php,v 1.14 2004/09/22 08:11:51 yeupou Exp $
+# $Id: mod.php,v 1.17 2004/11/24 09:19:47 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -24,7 +24,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-
 # Need search functions.
 require_directory("search");
 
@@ -46,6 +45,24 @@ if (db_numrows($result) > 0)
   # Defines the item link
   $item_link = utils_link("?func=detailitem&item_id=".$item_id, $item_name);
 
+  # Check whether this item is private or not. If it is private, show only to 
+  # the submitter or to people that got the right to see private items
+  unset($private_intro);
+  if (db_result($result,0,'privacy') == "2") 
+    {
+      if (member_check_private(0, $group_id)) 
+	{
+	  # Nothing worth being mentioned
+	}
+      elseif (db_result($result,0,'submitted_by') == user_getid()) 
+	{
+	  $private_intro = _("This item is private. However, you are allowed to read it as you submitted it.");
+	}
+      else 
+	{
+	  exit_error(_("This item is private. You are not listed as member allowed to read private items."));
+	}
+    }
 
   # Prepare all the necessary fields in case the user wants to 
   # Create a new task based on this bug
@@ -106,11 +123,12 @@ if (db_numrows($result) > 0)
 
   print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
 
+print form_header($PHP_SELF, $form_id, "post", 'enctype="multipart/form-data" name="item_form"');
+print form_input("hidden", "func", "postmoditem");
+print form_input("hidden", "group_id", $group_id);
+print form_input("hidden", "item_id", $item_id);
+
   print '
-    <form action="'.$PHP_SELF.'" method="post" enctype="multipart/form-data" name="item_form">
-    <input type="hidden" name="func" value="postmoditem">
-    <input type="hidden" name="group_id" value="'.$group_id.'">
-    <input type="hidden" name="item_id" value="'.$item_id.'">
 
     <table cellpadding="0" width="100%">
       <tr>
@@ -149,7 +167,10 @@ if (db_numrows($result) > 0)
 	  # Look for the field value in the database only if we missing
 	  # its values. If we already have a value, we are probably in
 	  # step 2 of a search on item/group (dependancy, reassignation).
-	  if (!$$field_name)
+          
+          # If nocache is set, we were explicetely asked to rely only
+          # on database content
+	  if (!$$field_name || $nocache)
 	    { $field_value = db_result($result,0,$field_name); }
 	  else
 	    { $field_value = $$field_name; }
@@ -220,13 +241,40 @@ if (db_numrows($result) > 0)
   # ################################ Comments 
 
   print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
+
   print '<table>
           <tr><td class="preinput">'
     ._("Use a Canned Response:").'&nbsp;</td><td width="70%">';
 
-  print trackers_canned_response_box ($group_id,'canned_response');
+  if ($canned_response == "!multiple!")
+    {
+     
+      $result_canned = trackers_data_get_canned_responses($group_id);
+      if (db_numrows($result_canned) > 0) 
+	{
 
-  print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&create_canned=1">['._("Or define a new Canned Response").']</a>';
+	  while ($canned = db_fetch_array($result_canned))
+	    {
+
+              print '<input type="checkbox" name="canned_response[]" value="'.$canned['bug_canned_id'].'" />'.$canned['title'];
+              print '<br />';
+
+	    }
+         }
+      else
+         {
+           print '<font class="warn">'._("Strangely enough, there is no canned
+response available.").'</font>';
+         }
+
+    }
+  else
+    {
+
+       print trackers_canned_response_box ($group_id,'canned_response');
+       print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&create_canned=1">['._("Or define a new Canned Response").']</a>';
+
+    }
 
   print '</td></tr><tr><td class="preinput">';
   print _("Comment Type:");
@@ -357,9 +405,10 @@ if (db_numrows($result) > 0)
 	  while (list($num, $tracker) = each($artifacts)) 
 	    { 
 	      if ($depends_search_only_project == "notany") 
-		{ $search_without_group_id = 0; }
-	      else
-		{ $search_without_group_id = 1; }
+		{ $GLOBALS['only_group_id'] = $group_id; }
+ 
+              # Do not ask for all words, 
+              $GLOBALS['exact'] = 0;
 
 	      $result_search = search_run($depends_search, $tracker, 0);
 	      $success = db_numrows($result_search) + $success;
@@ -375,7 +424,9 @@ if (db_numrows($result) > 0)
 			  # Right now only print id, summary and group.
 			  # We may change that depending on users feedback.
 			  print '<br />';
-			  print '&nbsp;&nbsp;&nbsp;<input type="checkbox" name="dependent_on_'.$tracker.'[]" value="'.$res_id.'">['.$tracker.' #'.$res_id.'] '.$res_summary.', '._("group").' '.group_getname($res_group);
+			  print '&nbsp;&nbsp;&nbsp;<input type="checkbox" name="dependent_on_'.$tracker.'[]" value="'.$res_id.'">'.$tracker.' #'.$res_id._(': ').$res_summary;
+                          if (group_getname($res_group)) 
+                            { print ', '._("group").' '.group_getname($res_group); }
 			}
 		    }
 		}
