@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: user.php,v 1.14 2004/09/22 08:11:51 yeupou Exp $
+# $Id: user.php,v 1.15 2004/11/22 08:25:50 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) ...
+#  Copyright 2004      (c) Mathieu Roy <yeupou--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -368,12 +368,13 @@ function user_unset_preference ($preference_name)
   global $user_pref;
   if (user_isloggedin()) {
     $preference_name=strtolower(trim($preference_name));
-    $result=db_query("DELETE FROM user_preferences WHERE user_id='".user_getid()."' AND preference_name='subject_line' LIMIT 1");
+    $result=db_query("DELETE FROM user_preferences WHERE user_id='".user_getid()."' AND preference_name='$preference_name' LIMIT 1");
 
     # Update the Preference cache if it was setup by a user_get_preference
     if (isset($user_pref))
       { unset($user_pref[$preference_name]); }
 
+    dbg("Remove pref $preference_name");
     return true;
   }
 }
