@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php,v 1.64 2004/09/22 08:11:51 yeupou Exp $
+# $Id: utils.php,v 1.65 2004/11/22 08:25:50 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -65,7 +65,7 @@ function utils_makereal ($data, $string="%PROJECT", $replacement=0)
 }
 
 # Add unavailable css class to a link if required
-function utils_link ($url, $title, $defaultclass=0, $available=1)
+function utils_link ($url, $title, $defaultclass=0, $available=1, $help=0)
 {
   if (!$available)
     { $defaultclass = 'unavailable'; }
@@ -74,10 +74,21 @@ function utils_link ($url, $title, $defaultclass=0, $available=1)
 
   if ($defaultclass) 
     { $return .= ' class="'.$defaultclass.'"'; }
+  if ($help) 
+    { $return .= ' title="'.$help.'"'; }
   $return .= '>'.$title.'</a>';
   return $return;
 }
 
+
+# Alias function
+function utils_altrow ($i)
+{
+  return html_get_alt_row_color ($i);
+}
+
+
+
 # This function returns a string of the date $value with the format $format
 # and if this date is not set, return the default value $default_value
 function format_date ($format,$value,$default_value = '-')
@@ -788,6 +799,8 @@ function utils_normalize_email ($address)
 
 function utils_antispam_email ($address)
 {
+  if (user_isloggedin())
+    { return $address; }
   $fakemail = preg_replace("/\\@/",' '._("--AT--").' ', $address);
   $fakemail = preg_replace("/\\./",' '._("--DOT--").' ', $fakemail);
   return $fakemail;
@@ -908,6 +921,18 @@ function fb ($msg, $error=0)
     }
 }
 
+# fb function to be used about database error when context of error is obvious
+function fb_dberror()
+{
+  fb(_("Error updating database"),1);
+}
+
+# fb function to be used about database error when context of error is obvious
+function fb_dbsuccess()
+{
+  fb(_("Database succesfully updated"));
+}
+
 # alias
 function util_help ($text, $explanation_array)
 {
