@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.46 2004/09/22 08:11:52 yeupou Exp $
+# $Id: index.php,v 1.48 2004/11/23 10:50:15 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -52,29 +52,32 @@ site_project_header(array('group'=>$group_id,'toptab'=>'ahome'));
 print '<h3><a href="'.$GLOBALS['sys_home'].'project/admin/editgroupinfo.php?group='.$group_name.'">'._("Edit Public Informations").'</a></h3>';
 print '<dd>'._("Edit project description...").'<br />';
 print _("Your current short description is:").' <i>"'. db_result($res_grp,0,'short_description').'"</i>';
-print '.</dd>';
+print '</dd>';
 
 print '<h3><a href="'.$GLOBALS['sys_home'].'project/admin/editgroupfeatures.php?group='.$group_name.'">'._("Active Features").'</a></h3>';
-print '<dd>'._("Define which features you want to use for this project.").'.</dd>';
+print '<dd>'._("Define which features you want to use for this project.").'</dd>';
 
 
 print '<h3><a href="'.$GLOBALS['sys_home'].'project/admin/useradmin.php?group='.$group_name.'">'._("Manage Members").'</a></h3>';
-print '<dd>'._("Add/Remove members to your project").'.</dd>';
+print '<dd>'._("Add/Remove members to your project.").'</dd>';
 
 print '<h3><a href="'.$GLOBALS['sys_home'].'project/admin/userperms.php?group='.$group_name.'">'._("Set Member Permissions").'</a></h3>';
-print '<dd>'._("Modify the rights of project members").'.</dd>';
+print '<dd>'._("Modify the rights of project members.").'</dd>';
 
 print '<h3><a href="'.$GLOBALS['sys_home'].'project/admin/editgroupnotifications.php?group='.$group_name.'">'._("Manage Email Notifications").'</a></h3>';
-print '<dd>'._("For every tracker, modify the type of notification (global/per category), the related address lists and the notification triggers").'.</dd>';
+print '<dd>'._("For every tracker, modify the type of notification (global/per category), the related address lists and the notification triggers.").'</dd>';
+
+print '<h3><a href="'.$GLOBALS['sys_home'].'project/admin/conf-copy.php?group='.$group_name.'">'._("Copy Configuration").'</a></h3>';
+print '<dd>'._("Copy the configuration of trackers of others project you are member of.").'</dd>';
 
 print '<h3><a href="'.$GLOBALS['sys_home'].'project/admin/history.php?group='.$group_name.'">'._("Show History").'</a></h3>';
-print '<dd>'.sprintf(_("Keep tracks of your %s project's modications"),$GLOBALS['sys_name']).'.</dd>';
+print '<dd>'.sprintf(_("Keep tracks of your %s project's modications."),$GLOBALS['sys_name']).'</dd>';
 
 print '<h3><a href="'.$GLOBALS['sys_home'].'people/createjob.php?group='.$group_name.'">'._("Post Jobs").'</a></h3>';
-print '<dd>'._("Add a job offer").'.</dd>';
+print '<dd>'._("Add a job offer.").'</dd>';
 
 print '<h3><a href="'.$GLOBALS['sys_home'].'people/editjob.php?group='.$group_name.'">'._("Edit Jobs").'</a></h3>';
-print '<dd>'._("Edit jobs offers for this project").'.</dd>';
+print '<dd>'._("Edit jobs offers for this project.").'</dd>';
 
 /*
 
