@@ -2,14 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: useradmin.php,v 1.8 2004/09/22 08:11:52 yeupou Exp $
-#
-#  Copyright 2003      (c) Frederik Orellana <frederik.orellana@cern.ch>
-#                          Derek Feichtinger <derek.feichtinger@cern.ch>
-#                          Mathieu Roy <yeupou--at--gnu.org>
-#
-#  Copyright 2004      (c) ...
+# $Id: useradmin.php,v 1.9 2004/11/23 12:11:57 yeupou Exp $
 #
+#  Copyright 2003-2004 (c) Frederik Orellana <frederik.orellana--cern.ch>
+#                          Derek Feichtinger <derek.feichtinger--cern.ch>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -38,7 +35,7 @@ function show_pending_users_list ($result, $group_id)
         "._("User(s) that have requested to be member of the Group are listed here. To approve his/their request(s), select his/their name(s) and click on the button below.")."
 	<form action=\"$PHP_SELF\" method=\"post\">
 	<input type=\"HIDDEN\" name=\"action\" VALUE=\"approve_for_group\">
-  <select name=\"user_id[]\" size=6 multiple>\n";
+  <select name=\"user_id[]\" size=\"10\" multiple>\n";
 
   while ($usr = db_fetch_array($result)) {
     print "<option value=".$usr[user_id].">".$usr[realname].
@@ -69,7 +66,7 @@ function show_all_users_remove_list ($result, $group_id)
         "._("To remove an user, or several, select his/their name(s) and click on the button below. Project's administrators cannot be removed unless they quit.")."
 	<form action=\"$PHP_SELF\" method=\"post\">
 	<input type=\"HIDDEN\" name=\"action\" VALUE=\"remove_from_group\">
-  <select name=\"user_id[]\" size=\"6\" multiple>\n";
+  <select name=\"user_id[]\" size=\"10\" multiple>\n";
 
   while ($usr = db_fetch_array($result)) {
     if (!member_check($usr[user_id], $group_id, "A"))
@@ -121,7 +118,7 @@ function show_all_users_add_list ($result, $group_id)
 	<P></P>
 	<form action=\"$PHP_SELF\" method=\"post\">
 	<input type=\"HIDDEN\" name=\"action\" VALUE=\"add_to_group\">
-  <select name=\"user_id[]\" size=6 multiple>\n";
+  <select name=\"user_id[]\" size=\"10\" multiple>\n";
 
   while ($usr = db_fetch_array($result)) {
       print "<option value=".$usr[user_id].">".$usr[realname].
