@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: confirmation.php,v 1.65 2004/09/22 08:11:52 yeupou Exp $
+# $Id: confirmation.php,v 1.67 2004/11/22 09:01:40 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -24,6 +24,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+define("ARTIFACT", "task");
 require "../include/pre.php";
 session_require(array('isloggedin'=>'1'));
 require "../include/vars.php";
@@ -38,7 +39,7 @@ if ($show_confirm && $rand_hash)
   $sql="SELECT * FROM groups WHERE group_id='$group_id' AND rand_hash='__$rand_hash'";
   $result=db_query($sql);
 
-  echo '
+  print '
 <h3>'._("Final Confirmation").'</h3>
 <h3 align="center"><font class="warn">'._("Do not click back button after this point!!").'</font></h3>
 
@@ -64,7 +65,7 @@ if ($show_confirm && $rand_hash)
     . '
 <h5>'._("Project Type").':</h5>
    ';
-  echo show_group_type_box('group_type',$group_type);
+  print show_group_type_box('group_type',$group_type);
   print '
 <h5>'._("License").':</h5>
 <select name="form_license">
@@ -75,19 +76,19 @@ if ($show_confirm && $rand_hash)
       print "<option value=\"$k\"";
       if ($k==db_result($result,0,'license'))
 	{
-	  echo ' selected';
+	  print ' selected';
 	}
       print ">$v</option>\n";
     }
-  echo '</select>';
-  echo '
+  print '</select>';
+  print '
 <h5>'._("Other License:").'</h5>
 <textarea name="form_license_other" wrap="virtual" cols="60" rows="10">'
     . db_result($result,0,'license_other') . '</textarea>
 <p>'
     ._("If you confirm it, your project registration will be saved, waiting for a system administrator to approve it. If you reject it, this registration will be discarded.").'
 </p>
-<p>
+<p class="center">
 <input type="submit" name="i_agree" value="'
     ._("Confirm").'">
 <input type="submit" name="i_disagree" value="'
@@ -148,7 +149,54 @@ else if ($i_agree && $group_id && $rand_hash)
      ."http://".$project->getTypeBaseHost().$GLOBALS['sys_home']."register/basicinfo.php?re_purpose=".rawurlencode($form_purpose)."&re_require_sw=".rawurlencode($form_required_sw)."&re_comments=".rawurlencode($form_comments)."&re_full_name=".rawurlencode($form_full_name)."&re_unix_name=".rawurlencode($unix_name)."\n"
      ."----RERegistration-URL-END-------\n";
 
-  $message_admin = "$message";
+  $message_admin = "
+Site Admin. Approval/Edition URL:
+ <".$GLOBALS['sys_https_url'].$GLOBALS['sys_home']."admin/groupedit.php?group_id=".$group_id.">
+
+
+###### ORIGINAL SUBMISSION DETAILS ######
+
+System Group Name:
+-----------------
+  $unix_name
+
+
+Full Name:
+----------
+  $form_full_name
+  
+
+Type:
+-----
+  $type
+
+
+License:
+-------- 
+  ".$LICENSE[$form_license]."
+
+
+Other License: 
+--------------
+  $form_license_other
+
+
+Description:
+------------
+  $form_purpose
+
+
+Other Software Required:
+------------------------
+  $form_required_sw
+
+
+Other Comments:
+---------------
+  $form_comments
+
+#########################################
+";
 
   # a mail for the submitter
   sendmail_mail($type_admin_email_address,
@@ -159,27 +207,61 @@ else if ($i_agree && $group_id && $rand_hash)
 		$type_admin_email_address);
 
 
-  # a mail for the moderators staff
-  sendmail_mail($user_email,
-		$type_admin_email_address,
-		"submission of $form_full_name - $type_base_host",
-		$message_admin,
-		0,0,0,
-		$user_email);
+  # a mail for the moderators staff!
+# Done automatically by the task tracker
+#  sendmail_mail($user_email,
+#		$type_admin_email_address,
+#		"submission of $form_full_name - $type_base_host",
+#		$message_admin,
+#		0,0,0,
+#		$user_email);
 
   # special case: the unix_group_name fit the sys_unix_group_name:
   #   this project must be activated.
   if ($GLOBALS['sys_group_id'] == $group_id)
     {
-      $result=db_query("UPDATE groups SET status='A' WHERE group_id='$group_id' AND rand_hash='__$rand_hash'");
+      db_query("UPDATE groups SET status='A' WHERE group_id='$group_id' AND rand_hash='__$rand_hash'");
+      # We also add a specific field for the task tracker
+      # (we need to copy the None field)
+      db_query("INSERT INTO task_field_value (bug_field_id,group_id,value_id,value,description,order_id,status) VALUES (103,$group_id,100,'None','',10,'P')");
+      db_query("INSERT INTO task_field_value (bug_field_id,group_id,value_id,value,description,order_id,status) VALUES (103,$group_id,1,'Project Approval','Pending project registration',11,'P')");
+
+    }
+  else
+    {
+      require_directory("trackers");
+      trackers_init($GLOBALS['sys_group_id']);
+      # Otherwise, create a new item on the admin task tracker
+      $vfl = array();
+      $vfl['category_id'] = '1';
+      $vfl['summary'] = 'Submission of '.$form_full_name;
+      $vfl['details'] = $message_admin;
+      $address = "";
+      $item_id = trackers_data_create_item($GLOBALS['sys_group_id'],$vfl,$address);
+      # send an email to notify the admins of the ite update
+      list($additional_address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
+      if ((trim($address) != "") && (trim($additional_address) != "")) 
+	{ $address .= ", "; }
+      $address .= $additional_address;
+      # exclude the submitter from the notification, he got a specific mail
+      # for himself
+      trackers_mail_followup($item_id, $address, false, user_getname());
+      fb(sprintf(_("Task #%s opened"),$item_id));
     }
 
-  $HTML->header(array('title'=>_("Registration Complete")));
+  if ($GLOBALS['sys_group_id'] != $group_id)
+    {
+      # get site-specific content, if it is not the localadmin project
+      site_header(array('title'=>_("Registration Complete")));
+      utils_get_content("register/confirmation");
+      site_footer(array());
+    }
+  else
+    {
+      # redirect to the trigger page
+      session_redirect($GLOBALS['sys_home']."admin/triggercreation.php?group_id=".$group_id);
+    }
 
-  # get site-specific content
-  utils_get_content("register/confirmation");
-
-  $HTML->footer(array());
 }
 else if ($i_disagree && $group_id && $rand_hash)
 {
@@ -187,7 +269,7 @@ else if ($i_disagree && $group_id && $rand_hash)
   $result=db_query("DELETE FROM groups "
 		   .	"WHERE group_id='$group_id' AND rand_hash='__$rand_hash'");
 
-  echo '
+  print '
 <h3>'._("Project Deleted").'</h3>
 <p>'._("Please try again any other time.").'</p>';
 
