@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.44 2004/06/28 14:21:32 yeupou Exp $
+# $Id: index.php,v 1.45 2004/11/22 08:25:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #                          Mathieu Roy <yeupou--at--gnu.org>
 # 
-#  Copyright 2004      (c) ...
+#  Copyright 2004      (c) Mathieu Roy <yeupou--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -249,8 +249,9 @@ else if ($type_of_search == 'bugs' ||
     {
       search_failed();
     }
-  elseif (($rows == 1) && ($GLOBALS['offset'] == 0))
+  elseif (($rows == 1) && ($GLOBALS['offset'] == 0 && (db_result($result, $i, 'privacy') != "2")))
     {
+      # no automatic redirection for private item, use the usual listing
       $bug = db_result($result, 0, 'bug_id');
       Header("Location: ".$GLOBALS['sys_home'].$type_of_search."/?func=detailitem&item_id=$bug");
     }
@@ -263,6 +264,7 @@ else if ($type_of_search == 'bugs' ||
       search_send_header();
 
       $title_arr = array();
+      $title_arr[] = _("Item Id");
       $title_arr[] = _("Item Summary");
       $title_arr[] = _("Group");
       $title_arr[] = _("Submitted By");
@@ -275,19 +277,20 @@ else if ($type_of_search == 'bugs' ||
       $j;
       for ( $i = 0; $i < $rows; $i++ )
 	{
-# Do not even show private item, apart to technician level members
-# and submitter
+          # Do even show private item
 	  if (db_result($result, $i, 'privacy') == "2" &&
-	      !member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') &&
+	      !member_check_private(0, $group_id)  &&
 	      db_result($result,$i,'user_name') != user_getname()) 
 	    {
 	      dbg("Private item.");
 	    }
 	  else 
 	    {
+
 	      $url = $GLOBALS['sys_home'].$type_of_search."/?func=detailitem&amp;item_id=".db_result($result, $i, "bug_id");
 	      
 	      print	'<tr class="'.html_get_alt_row_color($j).'">'
+		. '<td><a href="'.$url.'">#'.db_result($result, $i, "bug_id").'</a></td>'
 		. '<td><a href="'.$url.'">'.db_result($result, $i, "summary").'</a></td>'
 		. '<td><a href="'.$url.'">'.group_getname(db_result($result, $i, "group_id")).'</a></td>'
 		. "<td>".utils_user_link(db_result($result, $i, "user_name"))."</td>"
