@@ -2,13 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Savannah.pm,v 1.14 2004/01/31 00:56:19 yeupou Exp $
-#
-#
-#
-# Copyright 2003 (c) Mathieu Roy <yeupou@gnu.org>
-#
+# $Id: Savannah.pm,v 1.16 2004/09/24 11:36:54 yeupou Exp $
 #
+# Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,8 +19,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-#
-#
 
 ##
 ## Basic module that load any convenient submodules.
@@ -36,8 +30,10 @@ use DBI;
 use POSIX qw(strftime);
 
 # Load modules
+use Savannah::Version;
 use Savannah::Conf;
 use Savannah::DB;
+use Savannah::Mail;
 use Savannah::User;
 use Savannah::Groups;
 
