@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Conf.pm,v 1.9 2004/09/22 08:11:52 yeupou Exp $
+# $Id: Conf.pm,v 1.10 2004/11/22 08:25:51 yeupou Exp $
 #
 # Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #
@@ -57,12 +57,14 @@ if ($ENV{SAVANE_CONF}) {
     }
 }
 unless ($conffile) {
-    if (-e "/etc/savannah/savannah.conf.pl") {
-	our $conffile = "/etc/savannah/savannah.conf.pl";
-    } elsif (-e "/usr/etc/savannah/savannah.conf.pl") {
-	our $conffile = "/usr/etc/savannah/savannah.conf.pl";    
-    } elsif (-e "/usr/local/etc/savannah/savannah.conf.pl") {
-	our $conffile = "/usr/local/etc/savannah/savannah.conf.pl";    
+    if (-e "/etc/savane/savannah.conf.pl") {
+	our $conffile = "/etc/savane/savannah.conf.pl";
+    } elsif (-e "/etc/savannah/savannah.conf.pl") {
+	our $conffile = "/etc/savannah/savannah.conf.pl";  
+    } elsif (-e "/usr/etc/savane/savannah.conf.pl") {
+	our $conffile = "/usr/etc/savane/savannah.conf.pl";    
+    } elsif (-e "/usr/local/etc/savane/savannah.conf.pl") {
+	our $conffile = "/usr/local/etc/savane/savannah.conf.pl";    
     } else {
 	die "Unable to find any configuration file.\n\nStopped";
     }
