@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: DB.pm,v 1.13 2004/09/22 08:11:52 yeupou Exp $
+# $Id: DB.pm,v 1.14 2004/11/22 08:25:51 yeupou Exp $
 #
 # Copyright 2003 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -166,3 +166,17 @@ sub SetDBSettings {
 
     return $dbd->do("UPDATE ".$table." SET ".$value." WHERE ".$criterion);
 }
+
+
+## Delete entries in database
+# Use carefully
+sub DeleteDB {
+    my $table = $_[0];
+    my $criterion = $_[1];
+
+    unless ($table || $criterion) {
+	return 0;
+    }
+    
+    return $dbd->do("DELETE FROM ".$table." WHERE ".$criterion);
+}
