@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: User.pm,v 1.29 2004/02/29 12:33:46 yeupou Exp $
+# $Id: User.pm,v 1.30 2004/09/22 08:11:52 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou@gnu.org>
 # 
@@ -59,6 +59,12 @@ sub GetUserSettings {
     GetDBSettings("user", "user_name='$_[0]'", $_[1]);
 }
 
+## Get any pref for any user
+# arg0 : which user name
+# arg1 : which setting (none for all)
+sub GetUserPrefs { 
+    GetDBSettings("user_preferences", "user_id='".GetUserSettings($_[0], "user_id")."' AND preference_name='$_[1]'");
+}
 
 ## Show in a convenient way settings for a user
 # arg1 : which user name
@@ -66,6 +72,10 @@ sub PrintUserSettings {
     print join " | ", GetUserSettings($_[0]);
 }
 
+sub PrintUserPrefs {
+    print join " | ", GetUserPrefs($_[0]);
+}
+
 
 ## Update in a convenient way settings for a user
 # arg1 : which user name
@@ -75,6 +85,14 @@ sub SetUserSettings {
     SetDBSettings("user", "user_name='$_[0]'", "$_[1]='$_[2]'");
 }
 
+## Get any pref for any user
+# arg1 : which user name
+# arg2 : preference name
+# arg3 : new value
+sub SetUserPrefs { 
+    SetDBSettings("user_preferences", "user_id='".GetUserSettings($_[0], "user_id")."' AND preference_name='$_[1]'", "preference_value='$_[2]'");
+}
+
 
 ## Get list of groups for a user (contrary of GetGroupUsers
 # arg1 : which user name
@@ -98,7 +116,6 @@ sub GetUserName {
     return $dbd->selectrow_array("SELECT user_name FROM user WHERE user_id='".$_[0]."'");
 }
 
-
 #####
 ##### From the system
 #####
@@ -167,6 +184,12 @@ sub DeleteUser {
     return 1;
 }
 
+## Delete several users accounts. This function should be used carrefully.
+# arg1 : a criterion
+sub DeleteUsers {    
+    return $dbd->do("DELETE FROM user WHERE ".$_[0]) if $_[0];
+}
+
 
 ## It's many times usefull to get a list of username:mail for
 ## usual users, for instance for /etc/aliases
