@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Version.pm,v 1.5 2004/09/29 13:11:52 yeupou Exp $
+# $Id: Version.pm,v 1.7 2004/11/22 08:25:51 yeupou Exp $
 #
 # Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -32,7 +32,7 @@ our $version = 1;
 
 # Return a configuration item
 sub GetVersion {
-    return "1.0.4.1";
+    return "1.0.5";
 }
 
 # EOF
